@@ -47,6 +47,7 @@
 #include <kstandarddirs.h>
 #include <kdeversion.h>
 #include <qcheckbox.h>
+#include <krecentdocument.h>
 // Krusader includes
 #include "../krusader.h"
 #include "../resources.h"
@@ -70,6 +71,79 @@ KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd) {
 	return u;
 }
 
+KURL KChooseDir::getDir(QString text,const KURL& url, const KURL& cwd, bool &preserveDate ) {
+	KURLRequesterDlgForCopy *dlg = new KURLRequesterDlgForCopy(url.prettyURL(1),text, preserveDate, krApp,"" );        
+	dlg->urlRequester()->completionObject()->setDir(cwd.url());
+	KURL u;
+	if (dlg->exec() == QDialog::Accepted) {
+		u = vfs::fromPathOrURL(dlg->urlRequester()->completionObject()->replacedPath(
+			dlg->urlRequester()->lineEdit()->text()));
+		if (u.isRelativeURL(u.url())) {
+			KURL temp = u;
+			u = cwd;
+			u.addPath(temp.url());
+		}
+	}
+	preserveDate = dlg->preserveDate();
+	delete dlg;
+	return u;
+}
+
+KURLRequesterDlgForCopy::KURLRequesterDlgForCopy( const QString& urlName, const QString& _text, bool presDate, QWidget *parent,
+                                                  const char *name, bool modal )
+			:   KDialogBase( Plain, QString::null, Ok|Cancel|User1, Ok, parent, name, modal, true, KStdGuiItem::clear() ) {
+	QVBoxLayout * topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
+
+	QLabel * label = new QLabel( _text, plainPage() );
+	topLayout->addWidget( label );
+
+	urlRequester_ = new KURLRequester( urlName, plainPage(), "urlRequester" );
+	urlRequester_->setMinimumWidth( urlRequester_->sizeHint().width() * 3 );
+	topLayout->addWidget( urlRequester_ );
+	preserveDateCB = new QCheckBox(i18n("Preserve date (only for local targets)"), plainPage());        
+	preserveDateCB->setChecked( presDate );
+	topLayout->addWidget( preserveDateCB );
+	urlRequester_->setFocus();
+	connect( urlRequester_->lineEdit(), SIGNAL(textChanged(const QString&)),
+		SLOT(slotTextChanged(const QString&)) );
+	bool state = !urlName.isEmpty();
+	enableButtonOK( state );
+	enableButton( KDialogBase::User1, state );
+	connect( this, SIGNAL( user1Clicked() ), SLOT( slotClear() ) );
+}
+
+KURLRequesterDlgForCopy::KURLRequesterDlgForCopy() {
+}
+
+bool KURLRequesterDlgForCopy::preserveDate() {
+	return preserveDateCB->isChecked();
+}
+
+void KURLRequesterDlgForCopy::slotTextChanged(const QString & text) {
+	bool state = !text.stripWhiteSpace().isEmpty();
+	enableButtonOK( state );
+	enableButton( KDialogBase::User1, state );
+}
+
+void KURLRequesterDlgForCopy::slotClear() {
+	urlRequester_->clear();
+}
+
+KURL KURLRequesterDlgForCopy::selectedURL() const {
+	if ( result() == QDialog::Accepted ) {
+		KURL url = KURL::fromPathOrURL( urlRequester_->url() );
+		if( url.isValid() )
+			KRecentDocument::add(url);                                
+		return url;
+	}        
+	else
+		return KURL();
+}
+
+KURLRequester * KURLRequesterDlgForCopy::urlRequester() {
+	return urlRequester_;
+}
+
 KRGetDate::KRGetDate(QDate date, QWidget *parent, const char *name) : KDialog(parent, name,true,WStyle_DialogBorder) {
   dateWidget = new KDatePicker(this, date);
   dateWidget->resize(dateWidget->sizeHint());
@@ -136,25 +210,25 @@ UserSelectionModeDlg::UserSelectionModeDlg(QWidget *parent):
 	insertMovesDown = new QCheckBox(i18n("Insert moves down"), plainPage());
 	contextMenuImmediate = new QCheckBox(i18n("Right clicking pops context menu immediately"), plainPage());
 	
-	QToolTip::add(qtSelection, i18n("Checking this will create a mode based on KDE's style."));
+	QToolTip::add(qtSelection, i18n("If checked, use a mode based on KDE's style."));
 	QToolTip::add(leftButtonSelects, i18n("If checked, left clicking an item will select it."));
 	QToolTip::add(leftButtonPreserves, i18n("If checked, left clicking an item will select it, but will not"
 		" unselect other, already selected items."));
-	QToolTip::add(shiftCtrlLeftSelects, i18n("If checked, shift/ctrl left clicking will select items. Note:"
+	QToolTip::add(shiftCtrlLeftSelects, i18n("If checked, shift/ctrl left clicking will select items. \nNote:"
 		" This is meaningless if 'Left Button Selects' is checked."));
 	QToolTip::add(rightButtonSelects, i18n("If checked, right clicking an item will select it."));
 	QToolTip::add(rightButtonPreserves, i18n("If checked, right clicking an item will select it, but will not"
 		" unselect other, already selected items."));
-	QToolTip::add(shiftCtrlRightSelects, i18n("If checked, shift/ctrl right clicking will select items. Note:"
+	QToolTip::add(shiftCtrlRightSelects, i18n("If checked, shift/ctrl right clicking will select items. \nNote:"
 		" This is meaningless if 'Right Button Selects' is checked."));
 	QToolTip::add(spaceMovesDown, i18n("If checked, pressing the spacebar will select the current item and move"
-		" down. Otherwise, current item is selected, but remains the current item."));
+		" down. \nOtherwise, current item is selected, but remains the current item."));
 	QToolTip::add(spaceCalcSpace, i18n("If checked, pressing the spacebar while the current item is a folder,"
-		" will (except from selecting the folder) calculate space occupied by the folder (recursively)."));
+		" will (except from selecting the folder) \ncalculate space occupied by the folder (recursively)."));
 	QToolTip::add(insertMovesDown, i18n("If checked, pressing INSERT will select the current item, and move down"
-		" to the next item. Otherwise, current item is not changed."));
+		" to the next item. \nOtherwise, current item is not changed."));
 	QToolTip::add(contextMenuImmediate, i18n("If checked, right clicking will result in an immediate showing of"
-		" the context menu. Otherwise, user needs to click and hold the right mouse button for 500ms."));
+		" the context menu. \nOtherwise, user needs to click and hold the right mouse button for 500ms."));
 
 	layout->addMultiCellWidget(qtSelection, 0,0,0,0);
 	layout->addMultiCellWidget(leftButtonSelects, 1,1,0,0);
