@@ -33,6 +33,7 @@
 #include "../krusaderview.h"
 #include "../Panel/listpanel.h"
 #include "../kicons.h"
+#include "../Filter/filtertabs.h"
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
@@ -42,7 +43,8 @@
 #include <klocale.h>
 #include <kcombobox.h>
 #include <kiconloader.h>
-
+#include <kcursor.h>
+#include <qbitmap.h>
 #include "../resources.h"
 
 ///////////////////// initiation of the static members ////////////////////////
@@ -54,11 +56,16 @@ KRSpWidgets::KRSpWidgets(){
 }
 
 KRQuery KRSpWidgets::getMask(QString caption, bool nameOnly ) {
-  KRMaskChoiceSub *p=new KRMaskChoiceSub();
-  p->setCaption(caption);
-  p->exec();
-  if (p->selection->currentText()=="") return KRQuery();
-  else return KRQuery( p->selection->currentText() );
+  if( !nameOnly ) {
+    return FilterTabs::getQuery();
+  }
+  else {
+    KRMaskChoiceSub *p=new KRMaskChoiceSub();
+    p->setCaption(caption);
+    p->exec();
+    if (p->selection->currentText()=="") return KRQuery();
+    else return KRQuery( p->selection->currentText() );
+  }
 }
 
 /////////////////////////// newFTP ////////////////////////////////////////
@@ -70,14 +77,47 @@ KURL KRSpWidgets::newFTP() {
 	
 	QString protocol = p->prefix->currentText();
 	protocol.truncate(protocol.length() - 3); // remove the trailing ://
+	QString username = p->username->text().simplifyWhiteSpace();
+	QString password = p->password->text().simplifyWhiteSpace();
+	QString uri = p->url->currentText();
+
+	int uriStart = uri.findRev( '@' ); /* lets the user enter user and password in the URI field */
+	if( uriStart != -1 ) {
+		QString uriUser = uri.left( uriStart );
+		QString uriPsw = QString::null;
+		uri = uri.mid( uriStart + 1 );
+
+		int pswStart = uriUser.find( ':' ); /* getting the password name from the URL */
+		if( pswStart != -1 ) {
+			uriPsw = uriUser.mid( pswStart + 1 );
+			uriUser = uriUser.left( pswStart );
+		}
+
+		if( !uriUser.isEmpty() )           /* handling the ftp proxy username and password also */
+			username = username.isEmpty() ? uriUser : username + "@" + uriUser;
+
+		if( !uriPsw.isEmpty() )           /* handling the ftp proxy username and password also */
+			password = password.isEmpty() ? uriPsw : password + "@" + uriPsw;
+	}
+
+	QString host = uri;               /* separating the hostname and path from the uri */
+	QString path = QString::null;
+	int pathStart = uri.find( "/" );
+	if( pathStart != -1 ) {
+		path = host.mid( pathStart );
+		host = host.left( pathStart );
+	}
+
+	/* setting the parameters of the URL */
 	url.setProtocol(protocol);
-		url.setHost(p->url->currentText());
-	if (url.protocol().startsWith("ftp"))
-		url.setPort(p->port->cleanText().toShort());
-	if (!p->username->text().simplifyWhiteSpace().isEmpty())
-		url.setUser(p->username->text().simplifyWhiteSpace());
-	if (!p->password->text().simplifyWhiteSpace().isEmpty())
-		url.setPass(p->password->text().simplifyWhiteSpace());
+	url.setHost( host );
+	url.setPath( path );
+	if ( protocol == "ftp" || protocol == "fish" || protocol == "sftp" )
+		url.setPort(p->port->cleanText().toInt());
+	if (!username.isEmpty())
+		url.setUser( username );
+	if (!password.isEmpty())
+		url.setPass( password );
   
   return url;
 }
@@ -186,3 +226,71 @@ void KRMaskChoiceSub::acceptFromList(QListBoxItem *i) {
   selection->insertItem(i->text(),0);
   accept();
 }
+
+////////////////////////// QuickNavLineEdit ////////////////////
+
+QuickNavLineEdit::QuickNavLineEdit(const QString &string, QWidget *parent, const char *name):
+	KLineEdit(string, parent, name) { init(); }
+	
+QuickNavLineEdit::QuickNavLineEdit(QWidget *parent, const char *name): 
+	KLineEdit(parent, name) { init(); }
+
+void QuickNavLineEdit::init() {
+	_numOfSelectedChars=0;
+	_dummyDisplayed=false;
+	_pop=0;
+	//setCompletionMode( KGlobalSettings::CompletionPopupAuto );  ==> removed by public demand
+}
+
+void QuickNavLineEdit::leaveEvent(QEvent *) {
+	clearAll();
+}
+
+void QuickNavLineEdit::mousePressEvent( QMouseEvent *m ) {
+	if (m->state()!=ControlButton) clearAll();
+	else if (_numOfSelectedChars) 
+			emit returnPressed(text().left(_numOfSelectedChars));
+	KLineEdit::mousePressEvent(m);
+}
+
+void QuickNavLineEdit::mouseMoveEvent( QMouseEvent *m) {
+	if (m->state()!=ControlButton) { // works only with ctrl pressed
+		clearAll();
+		KLineEdit::mouseMoveEvent(m);
+		return;
+	}
+	
+	// find how much of the string we've selected (approx) 
+	// and select from from the start to the closet slash (on the right)
+	const QString tx = text().simplifyWhiteSpace();
+	if (tx.isEmpty()) {
+		clearAll();
+		return;
+	}
+	
+	int avgCharSize = fontMetrics().width(tx)/tx.length();
+	int numOfChars = m->x() / avgCharSize;
+	if (numOfChars) {
+		int idx = tx.find('/', numOfChars);
+		if (idx == -1 && !_dummyDisplayed) { // pointing on or after the current directory
+			if (_pop) delete _pop;
+
+			_pop = KPassivePopup::message( i18n("Quick Navigation"),
+				"<qt>" + i18n("Already at <i>%1</i>").arg(tx.left(idx)) + "</qt>",
+				*(KCursor::handCursor().bitmap()), this);
+
+			_dummyDisplayed=true;
+			_numOfSelectedChars=0;
+		} else if (idx>0 && idx!=_numOfSelectedChars) {
+			_numOfSelectedChars=idx;
+			if (_pop) delete _pop;
+			_dummyDisplayed=false;
+
+			_pop = KPassivePopup::message( i18n("Quick Navigation"),
+				"<qt>" + i18n("Click to go to <i>%1</i>").arg(tx.left(idx)) + "</qt>",
+				*(KCursor::handCursor().bitmap()), this );
+		}
+	}
+	KLineEdit::mouseMoveEvent(m);
+}
+
