@@ -28,6 +28,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <qtooltip.h>
 #include <klocale.h>
 #include <kglobalsettings.h>
 #include <qfontmetrics.h>
@@ -40,49 +41,60 @@
 KFnKeys::KFnKeys(QWidget *parent, char *name): QWidget(parent,name) {
 		krConfig->setGroup("Look&Feel");
 		////////////////////////////////
-		
+#define SETUP(TARGET) {\
+	TARGET->setMinimumWidth(45);\
+}
+				
 		setFont( KGlobalSettings::generalFont() );
 		layout=new QGridLayout(this,1,9);	// 9 keys
 		F2=new QPushButton( i18n("F2 Term  ") ,this);
-			QWhatsThis::add( F2, i18n( "<qt>Open terminal in current directory.<p>"
+			QToolTip::add( F2, i18n( "<qt>Open terminal in current directory.<p>"
 									   "You can define terminal in Konfigurator, "
 									   "default is konsole.</qt>" ) );
-			connect(F2,SIGNAL(clicked()), SLOTS,
-						SLOT(terminal()));
+			connect(F2,SIGNAL(clicked()), SLOTS, SLOT(terminal()));
+			SETUP(F2);
+			
 		F3=new QPushButton( i18n("F3 View  ") ,this);	
-			QWhatsThis::add( F3, i18n( "Open file in viewer." ) );
-			connect(F3,SIGNAL(clicked()), SLOTS,
-						SLOT(view()));
+			QToolTip::add( F3, i18n( "Open file in viewer." ) );
+			connect(F3,SIGNAL(clicked()), SLOTS, SLOT(view()));
+			SETUP(F3);
+		
 		F4=new QPushButton( i18n("F4 Edit  ") ,this);
-			QWhatsThis::add( F4, i18n( "<qt>Edit file.<p>"
+			QToolTip::add( F4, i18n( "<qt>Edit file.<p>"
 									   "Editor is configurable in Konfigurator, "
 									   "default is 'internal editor'.</qt>" ) );
-			connect(F4,SIGNAL(clicked()), SLOTS,
-						SLOT(edit()));
+			connect(F4,SIGNAL(clicked()), SLOTS, SLOT(edit()));
+			SETUP(F4);
+			
 		F5=new QPushButton( i18n("F5 Copy  ") ,this);	
-			QWhatsThis::add( F5, i18n( "Copy file from one panel to the other." ) );
-			connect(F5,SIGNAL(clicked()), SLOTS,
-						SLOT(copyFiles()));
+			QToolTip::add( F5, i18n( "Copy file from one panel to the other." ) );
+			connect(F5,SIGNAL(clicked()), SLOTS, SLOT(copyFiles()));
+			SETUP(F5);
+			
 		F6=new QPushButton( i18n("F6 Move") ,this);
-			QWhatsThis::add( F6, i18n( "Move file from one panel to the other." ) );
-			connect(F6,SIGNAL(clicked()), SLOTS,
-						SLOT(moveFiles()));
+			QToolTip::add( F6, i18n( "Move file from one panel to the other." ) );
+			connect(F6,SIGNAL(clicked()), SLOTS, SLOT(moveFiles()));
+			SETUP(F6);
+			
 		F7=new QPushButton( i18n("F7 Mkdir ") ,this);	
-			QWhatsThis::add( F7, i18n( "Create directory in current panel." ) );
-			connect(F7,SIGNAL(clicked()), SLOTS,
-						SLOT(mkdir()));
+			QToolTip::add( F7, i18n( "Create directory in current panel." ) );
+			connect(F7,SIGNAL(clicked()), SLOTS, SLOT(mkdir()));
+			SETUP(F7);
+			
 		F8=new QPushButton( i18n("F8 Delete") ,this);
-			QWhatsThis::add( F8, i18n( "Delete file, directory, etc." ) );
-			connect(F8,SIGNAL(clicked()), SLOTS,
-						SLOT(deleteFiles()));
+			QToolTip::add( F8, i18n( "Delete file, directory, etc." ) );
+			connect(F8,SIGNAL(clicked()), SLOTS, SLOT(deleteFiles()));
+			SETUP(F8);
+			
 		F9=new QPushButton( i18n("F9 Rename") ,this);	
-			QWhatsThis::add( F9, i18n( "Rename file, directory, etc." ) );
-			connect(F9,SIGNAL(clicked()), SLOTS,
-						SLOT(rename()));
+			QToolTip::add( F9, i18n( "Rename file, directory, etc." ) );
+			connect(F9,SIGNAL(clicked()), SLOTS, SLOT(rename()));
+			SETUP(F9);
+			
 		F10=new QPushButton( i18n("F10 Quit ") ,this);
-			QWhatsThis::add( F10, i18n( "Quit Krusader." ) );
-			connect(F10,SIGNAL(clicked()),krApp,
-						SLOT(quitKrusader()));
+			QToolTip::add( F10, i18n( "Quit Krusader." ) );
+			connect(F10,SIGNAL(clicked()),krApp, SLOT(quitKrusader()));
+			SETUP(F10);
 
     // set a tighter box around the keys
     int h = QFontMetrics(F2->font()).height()+2;
@@ -105,5 +117,17 @@ KFnKeys::KFnKeys(QWidget *parent, char *name): QWidget(parent,name) {
 		layout->activate();
 }
 
+void KFnKeys::updateShortcuts() {
+	F2->setText(krF2->shortcut().toString() + i18n(" Term"));
+	F3->setText(krF3->shortcut().toString() + i18n(" View"));
+	F4->setText(krF4->shortcut().toString() + i18n(" Edit"));
+	F5->setText(krF5->shortcut().toString() + i18n(" Copy"));
+	F6->setText(krF6->shortcut().toString() + i18n(" Move"));
+	F7->setText(krF7->shortcut().toString() + i18n(" Mkdir"));
+	F8->setText(krF8->shortcut().toString() + i18n(" Delete"));
+	F9->setText(krF9->shortcut().toString() + i18n(" Rename"));
+	F10->setText(krF10->shortcut().toString() + i18n(" Quit"));
+}
+
 #include "kfnkeys.moc"
 
