@@ -28,13 +28,14 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <qlabel.h>
+#include <qhbox.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+#include "krresulttabledialog.h"
 #include "kggeneral.h"
 #include "../defaults.h"
 #include "../krusader.h"
-#include <klocale.h>
-#include <qlabel.h>
-#include <qhbox.h>
-#include <kmessagebox.h>
 
 KgGeneral::KgGeneral( bool first, QWidget* parent,  const char* name ) :
       KonfiguratorPage( first, parent, name )
@@ -54,20 +55,21 @@ if( first )
   KONFIGURATOR_NAME_VALUE_TIP deleteMode[] =
   //            name            value    tooltip
     {{ i18n( "Delete files" ),  "false", i18n( "Files will be permanently deleted." ) },
-     { i18n( "Move to trash" ), "true",  i18n( "Files will be moved to Trash when deleted." ) }};
+     { i18n( "Move to trash" ), "true",  i18n( "Files will be moved to trash when deleted." ) }};
 
   KonfiguratorRadioButtons *trashRadio = createRadioButtonGroup( "General", "Move To Trash",
-      "true", 2, 0, deleteMode, 2, generalGrp, "myRadio", false );
+      _MoveToTrash ? "true" : "false", 2, 0, deleteMode, 2, generalGrp, "myRadio", false );
   generalGrid->addMultiCellWidget( trashRadio, 0, 0, 0, 1 );
 
   KonfiguratorCheckBox *checkBox = createCheckBox( "General", "Mimetype Magic", _MimetypeMagic,
                      i18n( "Use mimetype magic" ), generalGrp, false,
-                     i18n( "Mimetype magic allows better distinction of file types, but is slower" ) );
+                     i18n( "Mimetype magic allows better distinction of file types, but is slower." ) );
   generalGrid->addMultiCellWidget( checkBox, 1, 1, 0, 1 );
 
   QFrame *line1 = createLine( generalGrp, "line1" );
   generalGrid->addMultiCellWidget( line1, 2, 2, 0, 1 );
 
+  // editor
   QLabel *label1 = new QLabel( i18n( "Editor:" ), generalGrp, "EditorLabel" );
   generalGrid->addWidget( label1, 3, 0 );
   KonfiguratorURLRequester *urlReq = createURLRequester( "General", "Editor", "internal editor",
@@ -77,15 +79,48 @@ if( first )
   QLabel *label2 = new QLabel( i18n( "Hint: use 'internal editor' if you want to use Krusader's fast built-in editor" ), generalGrp, "EditorLabel" );
   generalGrid->addMultiCellWidget( label2, 4, 4, 0, 1 );
 
+QFrame *line2 = createLine( generalGrp, "line2" );
+  generalGrid->addMultiCellWidget( line2, 5, 5, 0, 1 );
+
+  // viewer
+
+  QLabel *label32 = new QLabel( i18n("Default viewer mode:"), generalGrp);
+  generalGrid->addWidget(label32, 6, 0);
+  
+  KONFIGURATOR_NAME_VALUE_TIP viewMode[] =
+  //            name            value    tooltip
+    {{ i18n( "Generic mode" ),  "generic", i18n( "Use the system's default viewer" ) },
+     { i18n( "Text mode" ), "text",  i18n( "View the file in text-only mode" ) }, 
+     { i18n( "Hex mode" ), "hex",  i18n( "View the file in hex-mode (better for binary files)" ) } };
+  KonfiguratorRadioButtons *viewRadio= createRadioButtonGroup( "General", "Default Viewer Mode",
+      "generic", 3, 0, viewMode, 3, generalGrp, "myRadio2", false );
+  generalGrid->addMultiCellWidget( viewRadio, 7, 7, 0, 1 );
+
+  KonfiguratorCheckBox *viewerCheckbox= createCheckBox( "General", "View In Separate Window", _ViewInSeparateWindow,
+                     i18n( "Viewer opens each file in a separate window" ), generalGrp, false,
+                     i18n( "If checked, each file will open in a separate window, otherwise, the viewer will work in a single, tabbed mode" ) );
+  generalGrid->addMultiCellWidget( viewerCheckbox, 8, 8, 0, 1 );
+
+
+  QFrame *line3 = createLine( generalGrp, "line3" );
+  generalGrid->addMultiCellWidget( line3, 9, 9, 0, 1 );
+
+	// terminal
   QLabel *label3 = new QLabel( i18n( "Terminal:" ), generalGrp, "TerminalLabel" );
-  generalGrid->addWidget( label3, 5, 0 );
+  generalGrid->addWidget( label3, 10, 0 );
   KonfiguratorURLRequester *urlReq2 = createURLRequester( "General", "Terminal", "konsole",
                                       generalGrp, false );
-  generalGrid->addWidget( urlReq2, 5, 1 );
+  generalGrid->addWidget( urlReq2, 10, 1 );
 
-  QFrame *line2 = createLine( generalGrp, "line2" );
-  generalGrid->addMultiCellWidget( line2, 6, 6, 0, 1 );
+  KonfiguratorCheckBox *checkBox1 = createCheckBox( "General", "Send CDs", _SendCDs,
+                     i18n( "Terminal Emulator sends Chdir on panel change" ), generalGrp, false,
+                     i18n( "When checked, whenever the panel is changed (for example, by pressing TAB), krusader changes the current directory in the terminal emulator." ) );
+  generalGrid->addMultiCellWidget( checkBox1, 11, 11, 0, 1 );
 
+  QFrame *line31 = createLine( generalGrp, "line4" );
+  generalGrid->addMultiCellWidget( line31, 12, 12, 0, 1 );
+
+	// temp dir
   QHBox *hbox = new QHBox( generalGrp, "hbox" );
   new QLabel( i18n( "Temp Directory:" ), hbox, "TempDirectory" );
   KonfiguratorURLRequester *urlReq3 = createURLRequester( "General", "Temp Directory", "/tmp/krusader.tmp",
@@ -93,11 +128,11 @@ if( first )
   urlReq3->setMode( KFile::Directory );
   connect( urlReq3->extension(), SIGNAL( applyManually(QObject *,QString, QString) ),
            this, SLOT( applyTempDir(QObject *,QString, QString) ) );
-  generalGrid->addMultiCellWidget( hbox, 7, 7, 0, 1 );
+  generalGrid->addMultiCellWidget( hbox, 13, 13, 0, 1 );
 
-  QLabel *label4 = new QLabel( i18n( "NOTE: You must have full permissions for the temporary directory!" ),
+  QLabel *label4 = new QLabel( i18n( "Note: you must have full permissions for the temporary directory!" ),
                                generalGrp, "NoteLabel"  );
-  generalGrid->addMultiCellWidget( label4, 8, 8, 0, 1 );
+  generalGrid->addMultiCellWidget( label4, 14, 14, 0, 1 );
 
   kgGeneralLayout->addWidget( generalGrp, 0 ,0 );
 }
@@ -113,26 +148,9 @@ void KgGeneral::applyTempDir(QObject *obj,QString cls, QString name)
 
 void KgGeneral::slotFindTools()
 {
-  #define PS(x) lst.contains(x)>0
-  QString info;
-  QStringList lst=Krusader::supportedTools(); // get list of availble tools
-
-  info+=i18n("Searching for tools...\nSearch results:\n\n");
-  if (PS("DIFF")) info+=i18n("diff: found ")+lst[lst.findIndex("DIFF") + 1]+i18n(", compare by content available.\n");
-  else info+=i18n("diff: no diff frontends found. Compare by content disabled.\nhint: Krusader supports Kompare, Kdiff3 and Xxdiff\n\n");
-
-  if (PS("MAIL")) info+=i18n("mail: found ")+lst[lst.findIndex("MAIL") + 1]+i18n(", sending files by email enabled.\n");
-  else info+=i18n("mail: no compatible mail-programs found. Sending files by email is disabled.\nhint: Krusader supports Kmail\n\n");
-
-  if (PS("RENAME")) info+=i18n("rename: found ")+lst[lst.findIndex("RENAME") + 1]+i18n(", multiple rename enabled.\n");
-  else info+=i18n("rename: no compatible rename-programs found. Multiple rename is disabled.\nhint: Krusader supports Krename\n\n");
-
-
-  info+=i18n("\nIf you install new tools, please install them");
-  info+=i18n("\nto your path, e.g. /usr/bin, /usr/local/bin, etc.");
-  info+=i18n("\nand-or (re)configure the Tools path in");
-  info+=i18n("\nKonfigurator->Dependencies if needed.");
-  KMessageBox::information(0,info,i18n("Results"));
+  KrResultTableDialog* dia = new KrResultTableDialog(this, KrResultTableDialog::Tool, i18n("Search results"), i18n("Searching for tools..."),
+    "package_settings", i18n("Make sure to install new tools in your <code>$PATH</code> (e.g. /usr/bin)"));
+  dia->exec();
 }
 
 #include "kggeneral.moc"
