@@ -34,7 +34,7 @@
 #include "../Dialogs/krdialogs.h"
 #include <qtabwidget.h>
 #include <klocale.h>
-#include <qtooltip.h>
+#include <qwhatsthis.h>
 #include <qvalidator.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
@@ -42,6 +42,12 @@
 #include <kstandarddirs.h>
 #include "../Panel/krselectionmode.h"
 
+#define PAGE_OPERATION     0
+#define PAGE_PANEL         1
+#define PAGE_TOOLBAR       2
+#define PAGE_KEYBINDINGS   3
+#define PAGE_PANELTOOLBAR  4
+
 KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
       KonfiguratorPage( first, parent, name )
 {
@@ -50,7 +56,7 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   kgLookAndFeelLayout->setMargin( 11 );
 
   //  ---------------------------- GENERAL TAB -------------------------------------
-  QTabWidget *tabWidget = new QTabWidget( parent, "tabWidget" );
+  tabWidget = new QTabWidget( parent, "tabWidget" );
 
   QWidget *tab = new QWidget( tabWidget, "tab" );
   tabWidget->insertTab( tab, i18n( "Operation" ) );
@@ -63,18 +69,19 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 
   KONFIGURATOR_CHECKBOX_PARAM settings[] =
   //   cfg_class  cfg_name                default             text                              restart tooltip
-    {{"Look&Feel","Warn On Exit",         _WarnOnExit,        i18n( "Warn on exit" ),           false,  i18n( "Display a warning when you try to exit Krusader." ) },
-     {"Look&Feel","Minimize To Tray",     _MinimizeToTray,    i18n( "Minimize to tray" ),       false,  i18n( "When minimizing Krusader, its icon will appear in the system tray instead of the taskbar." ) },
-     {"Look&Feel","Show Hidden",          _ShowHidden,        i18n( "Show hidden files" ),      false,  i18n( "Display the dot files" ) },
-     {"Look&Feel","Mark Dirs",            _MarkDirs,          i18n( "Automark directories" ),   false,  i18n( "When matching the select criteria, directories will also be marked" ) },
+    {{"Look&Feel","Warn On Exit",         _WarnOnExit,        i18n( "Warn on exit" ),           false,  i18n( "Display a warning when trying to close the main window." ) },
+     {"Look&Feel","Minimize To Tray",     _MinimizeToTray,    i18n( "Minimize to tray" ),       false,  i18n( "The icon will appear in the system tray instead of the taskbar, when Krusader is minimized." ) },
+     {"Look&Feel","Show Hidden",          _ShowHidden,        i18n( "Show hidden files" ),      false,  i18n( "Display files beginning with a dot." ) },
+     {"Look&Feel","Mark Dirs",            _MarkDirs,          i18n( "Automark directories" ),   false,  i18n( "When matching the select criteria, directories will also be marked." ) },
      {"Look&Feel","Case Sensative Sort",  _CaseSensativeSort, i18n( "Case sensitive sorting" ), true ,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
-     {"Look&Feel","Fullpath Tab Names",   _FullPathTabNames,  i18n( "Use full path tab names" ), true ,  i18n( "Display the full path in the Folder Tabs; otherwise, only the last part of the path will be displayed." ) },
-     //{"Look&Feel","Single Click Selects", false,              i18n( "Single click executes" ),   false,  i18n( "" ) },
+     {"Look&Feel","Fullpath Tab Names",   _FullPathTabNames,  i18n( "Use full path tab names" ), true ,  i18n( "Display the full path in the folder tabs. By default only the last part of the path is displayed." ) },
      {"Look&Feel","New Style Quicksearch",  _NewStyleQuicksearch, i18n( "New style quicksearch" ), false,  i18n( "Opens a quick search dialog box." ) },
      {"Look&Feel","Case Sensitive Quicksearch",  _CaseSensitiveQuicksearch, i18n( "Case sensitive quicksearch" ), false,  i18n( "All files beginning with capital letters appear before files beginning with non-capital letters (UNIX default)." ) },
+     {"Look&Feel","Numeric permissions",  _NumericPermissions, i18n( "Numeric Permissions"  ), true,  i18n( "Show octal numbers (0755) instead of the standard permissions (rwxr-xr-x) in the permission column.") },
+     {"Look&Feel","Show splashscreen",  _ShowSplashScreen, i18n( "Show splashscreen"  ), false,  i18n( "Display a splashscreen when starting krusader.") },
     };
 
-  cbs = createCheckBoxGroup( 2, 0, settings, 8/*9*/, lookFeelGrp );
+  cbs = createCheckBoxGroup( 2, 0, settings, 10, lookFeelGrp, 0, PAGE_OPERATION );
   lookFeelGrid->addWidget( cbs, 0, 0 );
   connect( cbs->find( "New Style Quicksearch" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
 
@@ -86,8 +93,8 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
    KONFIGURATOR_NAME_VALUE_TIP singleOrDoubleClick[] =
   //          name                                               value  tooltip
     {{ i18n( "Double-click selects (classic)" ),                   "0", i18n( "A single click on a file will select and focus, a double click opens the file or steps into the directory." ) },
-     { i18n( "Obey KDE's global selection policy" ),               "1", i18n( "Use the KDE Kcontrol setting: KDE Control Center->Peripherals->Mouse" ) }};    
-  KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, lookFeelGrp, "myLook&FeelRadio0", true );
+     { i18n( "Obey KDE's global selection policy" ),               "1", i18n( "Use KDE's global setting:<p><i>KDE Control Center -> Peripherals -> Mouse</i>" ) }};    
+  KonfiguratorRadioButtons *clickRadio = createRadioButtonGroup( "Look&Feel", "Single Click Selects", "0", 1, 0, singleOrDoubleClick, 2, lookFeelGrp, "myLook&FeelRadio0", true, PAGE_OPERATION );
   lookFeelGrid->addWidget( clickRadio, 8, 0 );
   
   
@@ -97,12 +104,12 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
             lookFeelGrp, "lookAndFeelLabel4" );
   KONFIGURATOR_NAME_VALUE_TIP mouseSelection[] =
   //            name                 value  tooltip
-    {{ i18n( "Krusader Mode" ),        "0", i18n( "Both keys allow selecting files. To select more than one file, hold the Ctrl key and click the left mouse button.\nRight-click menu is invoked using a short click on the right mouse button." ) },
-     { i18n( "Konqueror Mode" ),       "1", i18n( "Pressing the left mouse button selects files - you can click and select multiple files.\nRight-click menu is invoked using a short click on the right mouse button." ) },    
-     { i18n( "Total-Commander Mode" ), "2", i18n( "The left mouse button does not select, but sets the current file without affecting the current selection.\nThe right mouse button selects multiple files and the right-click menu is invoked by pressing\nand holding the right mouse button." ) },
+    {{ i18n( "Krusader Mode" ),        "0", i18n( "Both keys allow selecting files. To select more than one file, hold the Ctrl key and click the left mouse button. Right-click menu is invoked using a short click on the right mouse button." ) },
+     { i18n( "Konqueror Mode" ),       "1", i18n( "Pressing the left mouse button selects files - you can click and select multiple files. Right-click menu is invoked using a short click on the right mouse button." ) },    
+     { i18n( "Total-Commander Mode" ), "2", i18n( "The left mouse button does not select, but sets the current file without affecting the current selection. The right mouse button selects multiple files and the right-click menu is invoked by pressing and holding the right mouse button." ) },
 	  { i18n( "Custom Selection Mode" ),       "3", i18n( "Design your own selection mode!" ) }};
  mouseRadio = createRadioButtonGroup( "Look&Feel", "Mouse Selection",
-      "0", 1, 0, mouseSelection, 4, lookFeelGrp, "myLook&FeelRadio", true );
+      "0", 1, 0, mouseSelection, 4, lookFeelGrp, "myLook&FeelRadio", true, PAGE_OPERATION );
   lookFeelGrid->addWidget( mouseRadio, 11, 0 );
   connect(mouseRadio, SIGNAL(clicked(int)), this, SLOT(slotSelectionModeChanged(int)));
 	
@@ -120,7 +127,7 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 
   QHBox *hbox = new QHBox( panelGrp, "lookAndFeelHBox1" );
   new QLabel( i18n( "Panel font:" ), hbox, "lookAndFeelLabel" );
-  createFontChooser( "Look&Feel", "Filelist Font", _FilelistFont, hbox, true );
+  createFontChooser( "Look&Feel", "Filelist Font", _FilelistFont, hbox, true, PAGE_PANEL );
   createSpacer ( hbox );
   panelGrid->addWidget( hbox, 0, 0 );
 
@@ -132,32 +139,12 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
      { i18n( "22" ),  "22" },
      { i18n( "32" ),  "32" },
      { i18n( "48" ),  "48" }};
-  KonfiguratorComboBox *iconCombo = createComboBox( "Look&Feel", "Filelist Icon Size", _FilelistIconSize, iconSizes, 4, hbox2, true, true );
+  KonfiguratorComboBox *iconCombo = createComboBox( "Look&Feel", "Filelist Icon Size", _FilelistIconSize, iconSizes, 4, hbox2, true, true, PAGE_PANEL );
   iconCombo->lineEdit()->setValidator( new QRegExpValidator( QRegExp( "[1-9]\\d{0,1}" ), iconCombo ) );
   createSpacer ( hbox2 );
   panelGrid->addWidget( hbox2, 1, 0 );
 
-  panelGrid->addWidget( createLine( panelGrp, "lookSep2" ), 2, 0 );
-
-  addLabel( panelGrid, 3, 0, i18n( "Show Columns:" ),
-            panelGrp, "panelLabel" );
-
-  KONFIGURATOR_CHECKBOX_PARAM fields[] =
-  //   cfg_class  cfg_name                default text                                  restart tooltip
-    {{"Look&Feel","Ext Column",           true,   i18n( "Extension" ),           true ,  i18n( "Show the last part of the filename (part after the last dot) in the Extension Column and\nnot as a complete filename in the Name Column like e.g. Konqueror does." ) },
-     {"Look&Feel","Mime Column",          false,  i18n( "Mimetype" ),            true ,  i18n( "Show the Mimetype Column" ) },
-     {"Look&Feel","Size Column",          true,   i18n( "Size" ),                true ,  i18n( "Show the Size Column" ) },
-     {"Look&Feel","DateTime Column",      true,   i18n( "Date and Time" ),       true ,  i18n( "Show the Date and Time Column" ) },
-     {"Look&Feel","Perm Column",          false,  i18n( "Permission" ),          true ,  i18n( "Show the Full Permissions Column, e.g. '-rw-r--r--'" ) },
-     {"Look&Feel","KrPerm Column",        true,   i18n( "Krusader Permission" ), true ,  i18n( "Show only the rights of the current user, e.g. '-rw'" ) },
-     {"Look&Feel","Owner Column",         false,  i18n( "Owner" ),               true ,  i18n( "Show the Owner Column" ) },
-     {"Look&Feel","Group Column",         false,  i18n( "Group" ),               true ,  i18n( "Show the Group Column" ) },
-    };
-
-  KonfiguratorCheckBoxGroup *flds = createCheckBoxGroup( 0, 4, fields, 8, panelGrp );
-  panelGrid->addWidget( flds, 4, 0 );
-
-  panelGrid->addWidget( createLine( panelGrp, "lookSep3" ), 5, 0 );
+  panelGrid->addWidget( createLine( panelGrp, "lookSep3" ), 2, 0 );
 
   KONFIGURATOR_CHECKBOX_PARAM panelSettings[] =
   //   cfg_class  cfg_name                default text                                  restart tooltip
@@ -166,8 +153,8 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
 	 {"Look&Feel","Human Readable Size",  _HumanReadableSize, i18n( "Use human-readable file size" ), true ,  i18n( "File sizes are displayed in B, KB, MB and GB, not just in bytes." ) },
     };
 
-  KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup( 0, 2, panelSettings, 2, panelGrp );
-  panelGrid->addWidget( panelSett, 6, 0 );
+  KonfiguratorCheckBoxGroup *panelSett = createCheckBoxGroup( 0, 2, panelSettings, 2, panelGrp, 0, PAGE_PANEL );
+  panelGrid->addWidget( panelSett, 3, 0 );
   
   panelLayout->addWidget( panelGrp, 0, 0 );
 
@@ -176,17 +163,17 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   tabWidget->insertTab( tab_2, i18n( "Toolbar" ) );
 
   toolBarLayout = new QGridLayout( tab_2 );
-  KonfiguratorEditToolbarWidget *editToolbar = new KonfiguratorEditToolbarWidget(krApp->factory(),tab_2);
+  KonfiguratorEditToolbarWidget *editToolbar = new KonfiguratorEditToolbarWidget(krApp->factory(),tab_2, false, PAGE_TOOLBAR );
   connect( editToolbar, SIGNAL( reload( KonfiguratorEditToolbarWidget * ) ), this, SLOT( slotReload( KonfiguratorEditToolbarWidget *) ) );
   toolBarLayout->addWidget(editToolbar->editToolbarWidget(),0,0);
   registerObject( editToolbar );
 
   //  -------------------------- KEY-BINDINGS TAB ----------------------------------
   tab_3 = new QWidget( tabWidget, "tab_3" );
-  tabWidget->insertTab( tab_3, i18n( "Key-bindings" ) );
+  tabWidget->insertTab( tab_3, i18n( "Keybindings" ) );
 
   keyBindingsLayout = new QGridLayout( tab_3 );
-  keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3);
+  keyBindings = new KonfiguratorKeyChooser(krApp->actionCollection(),tab_3, false, PAGE_KEYBINDINGS );
   connect( keyBindings, SIGNAL( reload( KonfiguratorKeyChooser * ) ), this, SLOT( slotReload( KonfiguratorKeyChooser *) ) );
   keyBindingsLayout->addMultiCellWidget(keyBindings->keyChooserWidget(),0,0,0,2);
   registerObject( keyBindings );
@@ -194,10 +181,10 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   // import and export shortcuts
   KPushButton *importBtn = new KPushButton(i18n("Import shortcuts"),tab_3);
   keyBindingsLayout->addWidget(importBtn,1,0);
-  QToolTip::add(  importBtn, i18n( "Load a Key-binding profile, e.g., total_commander.keymap" ) );
+  QWhatsThis::add( importBtn, i18n( "Load a keybinding profile, e.g., total_commander.keymap" ) );
   KPushButton *exportBtn = new KPushButton(i18n("Export shortcuts"),tab_3);
   keyBindingsLayout->addWidget(exportBtn,1,1);
-  QToolTip::add(  exportBtn, i18n( "Save current Key-bindings in a keymap file." ) );
+  QWhatsThis::add( exportBtn, i18n( "Save current keybindings in a keymap file." ) );
   keyBindingsLayout->addWidget(createSpacer(tab_3, "tab3spacer"), 1,2);
   connect(importBtn, SIGNAL(clicked()), this, SLOT(slotImportShortcuts()));
   connect(exportBtn, SIGNAL(clicked()), this, SLOT(slotExportShortcuts()));
@@ -211,11 +198,11 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   panelToolbarVLayout->setMargin( 11 );
 
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarActiveCheckbox[] = 
-  //   cfg_class    cfg_name                default        text                             restart tooltip
-    {{"Look&Feel", "Panel Toolbar visible", _PanelToolBar, i18n( "Show Panel Toolbar" ), false,  i18n( "Krusader will display the Panel Toolbar." ) }
+  //   cfg_class    cfg_name                default        text                          restart tooltip
+    {{"Look&Feel", "Panel Toolbar visible", _PanelToolBar, i18n( "Show Panel Toolbar" ), true,   i18n( "The panel toolbar will be visible." ) }
   };
 
-  panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, "panelToolbarActive");
+  panelToolbarActive = createCheckBoxGroup( 1, 0, panelToolbarActiveCheckbox, 1, tab_4, "panelToolbarActive", PAGE_PANELTOOLBAR);
   connect( panelToolbarActive->find( "Panel Toolbar visible" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotEnablePanelToolbar() ) );
     
   QGroupBox * panelToolbarGrp = createFrame( i18n( "Visible Panel Toolbar buttons" ), tab_4, "panelToolbarGrp");
@@ -224,17 +211,18 @@ KgLookFeel::KgLookFeel( bool first, QWidget* parent,  const char* name ) :
   KONFIGURATOR_CHECKBOX_PARAM panelToolbarCheckboxes[] = 
     {
   //   cfg_class    cfg_name                default             text                       restart tooltip
+     {"Look&Feel",  "Clear Location Bar Visible",  _ClearLocation,      i18n( "Clear location bar button" ),    true ,  i18n( "Clears the location bar" ) },
      {"Look&Feel",  "Open Button Visible",  _Open,      i18n( "Open button" ),     true ,  i18n( "Opens the directory browser." ) },
      {"Look&Feel",  "Equal Button Visible", _cdOther,   i18n( "Equal button (=)" ),true ,  i18n( "Changes the panel directory to the other panel directory." ) },
      {"Look&Feel",  "Up Button Visible",    _cdUp,      i18n( "Up button (..)" ),  true ,  i18n( "Changes the panel directory to the parent directory." ) },
      {"Look&Feel",  "Home Button Visible",  _cdHome,    i18n( "Home button (~)" ), true ,  i18n( "Changes the panel directory to the home directory." ) },
      {"Look&Feel",  "Root Button Visible",  _cdRoot,    i18n( "Root button (/)" ), true ,  i18n( "Changes the panel directory to the root directory." ) },
-     {"Look&Feel",  "SyncBrowse Button Visible",  _syncBrowseButton,    i18n( "Toggle-button for sync-browsing" ), true ,  i18n( "Each directory-change in the panel is also performed in the other panel." ) },
+     {"Look&Feel",  "SyncBrowse Button Visible",  _syncBrowseButton,    i18n( "Toggle-button for sync-browsing" ), true ,  i18n( "Each directory change in the panel is also performed in the other panel." ) },
     };
   
   
-  pnlcbs = createCheckBoxGroup(1, 0, panelToolbarCheckboxes, 6,
-                                       panelToolbarGrp, "panelToolbarChecks");
+  pnlcbs = createCheckBoxGroup(1, 0, panelToolbarCheckboxes, 7,
+                                       panelToolbarGrp, "panelToolbarChecks", PAGE_PANELTOOLBAR);
   
   panelToolbarVLayout->addWidget( panelToolbarActive, 0, 0 );
   panelToolbarGrid->addWidget( pnlcbs, 0, 0 );
@@ -286,6 +274,7 @@ void KgLookFeel::slotEnablePanelToolbar()
   pnlcbs->find( "Up Button Visible"       )->setEnabled(enableTB);
   pnlcbs->find( "Equal Button Visible"    )->setEnabled(enableTB);
   pnlcbs->find( "Open Button Visible"     )->setEnabled(enableTB);  
+  pnlcbs->find("SyncBrowse Button Visible")->setEnabled(enableTB);  
 }
 
 void KgLookFeel::slotImportShortcuts() {
@@ -299,8 +288,7 @@ void KgLookFeel::slotImportShortcuts() {
 	if (info.open(IO_ReadOnly)) {
 		QTextStream stream(&info);
 		QStringList infoText = QStringList::split("\n", stream.read());
-		if (KMessageBox::questionYesNoList(krApp, i18n("The following information was attached to the keymap.\n"
-				"Are you sure you want to import this keymap ?"), infoText)!=KMessageBox::Yes)
+		if (KMessageBox::questionYesNoList(krApp, i18n("The following information was attached to the keymap. Are you sure you want to import this keymap ?"), infoText)!=KMessageBox::Yes)
 			return;
 	}
 	// ok, import away
@@ -323,5 +311,9 @@ void KgLookFeel::slotSelectionModeChanged(int mode) {
 	}
 }
 
+int KgLookFeel::activeSubPage() {
+	return tabWidget->currentPageIndex();
+}
+
 #include "kglookfeel.moc"
 
