@@ -144,11 +144,7 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   setMainWidget(widget);
   show();
 
-  while( isShown() )
-  {
-    qApp->processEvents();
-    qApp->eventLoop()->processEvents( QEventLoop::AllEvents|QEventLoop::WaitForMore);
-  }
+  exec();
 }
 
 void LocateDlg::slotUser1()   /* The stop / feed to listbox button */
@@ -244,7 +240,7 @@ void LocateDlg::slotUser3()   /* The locate button */
     enableButton( KDialogBase::User1, false ); /* disable the stop button */
     isFeedToListBox = false;
   }else{
-    setButtonText( KDialogBase::User1, "Feed to listbox" ); /* feed to listbox */
+    setButtonText( KDialogBase::User1, i18n("Feed to listbox") ); /* feed to listbox */
     isFeedToListBox = true;
   }
 }
