@@ -267,6 +267,21 @@ KrViewItem *KrDetailedView::preAddItem( vfile *vf ) {
 	return new KrDetailedViewItem( this, lastItem(), vf );
 }
 
+bool KrDetailedView::preDelItem(KrViewItem *item) {
+   /* KDE HACK START - the renaming item is not disappeared after delete */
+   /* solution: we send an ESC key event to terminate the rename */
+   if( item ) {
+      QListViewItem * viewItem = dynamic_cast<QListViewItem*>( item );
+      if( viewItem == currentlyRenamedItem ) {
+         currentlyRenamedItem = 0;
+         QKeyEvent escEvent( QEvent::KeyPress, Key_Escape, 27, 0 );
+         QApplication::sendEvent( renameLineEdit(), &escEvent );
+      }
+   }
+   /* KDE HACK END */
+   return true;
+}
+
 void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
    QListViewItem * item = firstChild();
    QListViewItem *currentItem = item;
@@ -326,7 +341,7 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
    // re-enable sorting
    setSorting( cl, as );
    sort();
-	
+
    if ( !currentItem )
       currentItem = firstChild();
    KListView::setCurrentItem( currentItem );
@@ -348,7 +363,16 @@ void KrDetailedView::setCurrentItem( const QString& name ) {
 }
 
 void KrDetailedView::clear() {
-	op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
+   /* KDE HACK START - the renaming item is not disappeared after clear */
+   /* solution: we send an ESC key event to terminate the rename */
+   if( currentlyRenamedItem ) {
+      currentlyRenamedItem = 0;
+      QKeyEvent escEvent( QEvent::KeyPress, Key_Escape, 27, 0 );
+      QApplication::sendEvent( renameLineEdit(), &escEvent );
+   }
+   /* KDE HACK END */
+
+   op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
    KListView::clear();
    KrView::clear();
 }
@@ -597,8 +621,17 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
    if (callDefaultHandler)
    {
      dragStartPos = QPoint( -1, -1 );
+
+     QString name = QString::null;    // will the file be deleted by the mouse event?
+     if( newCurrent )                 // save the name of the file
+       name = static_cast<KrDetailedViewItem*>( newCurrent ) ->name();
+
      KListView::contentsMousePressEvent( e );
+
+     if( name.isEmpty() || _dict.find( name ) == 0 ) // is the file still valid?
+       newCurrent = 0;                // if not, don't do any crash...
    }
+
    //   if (i != 0) // comment in, if click sould NOT select
    //     setSelected(i, FALSE);
    if (newCurrent) QListView::setCurrentItem(newCurrent);
@@ -985,9 +1018,9 @@ void KrDetailedView::rename( QListViewItem * item, int c ) {
       item->setText( COLUMN( Name ), static_cast<KrDetailedViewItem*>( item ) ->name() );
       item->setText( COLUMN( Extention ), QString::null );
       repaintItem( item );
-      currentlyRenamedItem = item;
    }
 
+   currentlyRenamedItem = item;
    renameLineEdit()->setBackgroundMode(Qt::FixedColor);
    renameLineEdit()->setPaletteBackgroundColor(Qt::white);
    renameLineEdit()->setPaletteForegroundColor(Qt::black);
@@ -1029,6 +1062,9 @@ void KrDetailedView::renameCurrentItem() {
 }
 
 void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
+   if( currentlyRenamedItem == 0 )
+      return;
+
    if ( !it ) { // major failure - call developers
       krOut << "Major failure at inplaceRenameFinished(): item is null" << endl;
       return;
@@ -1071,6 +1107,8 @@ void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
 // TODO: move the whole quicksearch mess out of here and into krview
 void KrDetailedView::quickSearch( const QString & str, int direction ) {
    KrViewItem * item = getCurrentKrViewItem();
+   if (!item)
+      return;
    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
    bool caseSensitive = _config->readBoolEntry( "Case Sensitive Quicksearch", _CaseSensitiveQuicksearch );
    if ( !direction ) {
@@ -1178,7 +1216,7 @@ bool KrDetailedView::eventFilter( QObject * watched, QEvent * e )
 
 void KrDetailedView::makeItemVisible( const KrViewItem *item ) {
 //	qApp->processEvents();  // Please don't remove the comment. Causes crash if it is inserted!
-	ensureItemVisible( static_cast<const KrDetailedViewItem*>( item ) );
+	ensureItemVisible( static_cast<const KrDetailedViewItem*>( item ) ); 
 }
 
 void KrDetailedView::initOperator() {
