@@ -39,26 +39,27 @@ class QString;
 class QPixmap;
 
 class KrViewItem {
+	friend class KrView;
+
 public:
-   virtual QString name() const = 0;
-   virtual bool isDir() const = 0;
-   virtual bool isExecutable() const = 0;
-   virtual KIO::filesize_t size() const = 0;
-   virtual QString dateTime() const = 0;
-   virtual time_t getTime_t() const = 0;
-   virtual QString mime() const = 0;
-   virtual QString symlinkDest() const = 0;
-   virtual bool isSymLink() const = 0;
-   virtual QString description() const = 0;
+   virtual inline QString name() const { return _vf->vfile_getName(); }
+   virtual QString dateTime() const;
+   virtual QString description() const;
    virtual bool isSelected() const = 0;
    virtual void setSelected( bool s ) = 0;
-   virtual QPixmap icon() = 0;
+   virtual QPixmap icon();
    
 	KrViewItem(vfile *vf, const KrViewProperties* properties): _vf(vf), dummyVfile(false), _viewProperties(properties) {}
    virtual ~KrViewItem() { if (dummyVfile) delete _vf; }
-   virtual vfile* getVfile() { return _vf; }
 		
+   // DON'T USE THOSE OUTSIDE THE VIEWS!!!
+   virtual inline const vfile* getVfile() const { return _vf; }
+   virtual inline vfile* getMutableVfile() { return _vf; }
+
 protected:
+	// used INTERNALLY when calculation of dir size changes the displayed size of the item
+	inline void setSize(KIO::filesize_t size) { _vf->vfile_setSize(size); }
+
 	vfile* _vf;			// each view item holds a pointer to a corrosponding vfile for fast access	
 	bool dummyVfile;	// used in case our item represents the ".." (updir) item
 	const KrViewProperties* _viewProperties;
