@@ -28,6 +28,8 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 *                                                                         *
 ***************************************************************************/
 
+//#define TESTING_BRIEF_VIEW
+
 #include <unistd.h>
 #include <sys/param.h>
 // QT includes
@@ -48,11 +50,9 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <kmimetype.h>
 #include <kurl.h>
 #include <ktrader.h>
-#include <krun.h>
 #include <kopenwith.h>
 #include <kuserprofile.h>
 #include <kiconloader.h>
-#include <kshred.h>
 #include <kcursor.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
@@ -84,6 +84,9 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../Dialogs/krspecialwidgets.h"
 #include "../GUI/kcmdline.h"
 #include "krdetailedview.h"
+#ifdef TESTING_BRIEF_VIEW
+#include "krbriefview.h"
+#endif
 #include "krpreviewpopup.h"
 #include "../GUI/dirhistorybutton.h"
 #include "../GUI/dirhistoryqueue.h"
@@ -92,6 +95,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "panelpopup.h" 
 #include "../UserAction/useractionpopupmenu.h"
 #include "../Dialogs/popularurls.h"
+#include "krpopupmenu.h"
 
 #ifdef __LIBKONQ__
 #include <konq_popupmenu.h>
@@ -103,11 +107,11 @@ typedef QValueList<KServiceOffer> OfferList;
 #define URL(X) KURL::fromPathOrURL(X)
 
 /////////////////////////////////////////////////////
-// 					The list panel constructor             //
+// 					The list panel constructor       //
 /////////////////////////////////////////////////////
 ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
       QWidget( parent, name ), colorMask( 255 ), compareMode( false ), currDragItem( 0 ), statsAgent( 0 ), 
-		quickSearch( 0 ), cdRootButton( 0 ), cdUpButton( 0 ), popupBtn(0), popup(0), _left( left ), inlineRefreshJob(0) {
+		quickSearch( 0 ), cdRootButton( 0 ), cdUpButton( 0 ), popupBtn(0), popup(0),inlineRefreshJob(0), _left( left ) {
 
    func = new ListPanelFunc( this );
    setAcceptDrops( true );
@@ -164,7 +168,7 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
 	inlineRefreshCancelButton->setFixedSize( 22, 20 );
 	inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", KIcon::Toolbar, 16));
 	connect(inlineRefreshCancelButton, SIGNAL(clicked()), this, SLOT(inlineRefreshCancel()));
-	
+
 	// a quick button to open the popup panel
 	popupBtn = new QToolButton( this, "popupbtn" );
 	popupBtn->setFixedSize( 22, 20 );
@@ -183,7 +187,17 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    quickSearch->setMaximumHeight( sheight );
 
    QHBox * hbox = new QHBox( this );
-   origin = new KURLRequester( hbox );
+
+	// clear-origin button
+	bool clearButton = krConfig->readBoolEntry("Clear Location Bar Visible", _ClearLocation);
+	if (clearButton){
+		clearOrigin = new QToolButton(hbox, "clearorigin");
+		clearOrigin->setPixmap(krLoader->loadIcon("locationbar_erase", KIcon::Toolbar, 16));
+		QToolTip::add(  clearOrigin, i18n( "Clear the location bar" ) );
+	}
+	
+	QuickNavLineEdit *qnle = new QuickNavLineEdit(this);
+   origin = new KURLRequester( qnle, hbox );
    QPixmap pixMap = origin->button() ->iconSet() ->pixmap( QIconSet::Small, QIconSet::Normal );
    origin->button() ->setFixedSize( pixMap.width() + 4, pixMap.height() + 4 );
    QWhatsThis::add
@@ -197,7 +211,15 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    origin->setMode( KFile::Directory | KFile::ExistingOnly );
    connect( origin, SIGNAL( returnPressed( const QString& ) ), func, SLOT( openUrl( const QString& ) ) );
    connect( origin, SIGNAL( urlSelected( const QString& ) ), func, SLOT( openUrl( const QString& ) ) );
-
+   
+	// this is here on purpose, do not move up!
+	if (clearButton) {
+		clearOrigin->setFixedSize( 20, origin->button() ->height() );
+		connect(clearOrigin, SIGNAL(clicked()), origin->lineEdit(), SLOT(clear()));
+		connect(clearOrigin, SIGNAL(clicked()), origin->lineEdit(), SLOT(setFocus()));
+	}
+	//
+   
    cdOtherButton = new QToolButton( hbox, "cdOtherButton" );
    cdOtherButton->setFixedSize( 20, origin->button() ->height() );
    cdOtherButton->setText( i18n( "=" ) );
@@ -231,19 +253,53 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
 	QSplitter *splt = new QSplitter(this);
 	splt->setChildrenCollapsible(true);
 	splt->setOrientation(QObject::Vertical);
-	
-   view = new KrDetailedView( splt, this, _left, krConfig );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( executed( QString& ) ), func, SLOT( execute( QString& ) ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( needFocus() ), this, SLOT( slotFocusOnMe() ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( selectionChanged() ), this, SLOT( slotUpdateTotals() ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( itemDescription( QString& ) ), krApp, SLOT( statusBarUpdate( QString& ) ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( contextMenu( const QPoint & ) ), this, SLOT( popRightClickMenu( const QPoint & ) ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ), this, SLOT( popEmptyRightClickMenu( QListViewItem *, const QPoint &, int ) ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( letsDrag( QStringList, QPixmap ) ), this, SLOT( startDragging( QStringList, QPixmap ) ) );
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( gotDrop( QDropEvent * ) ), this, SLOT( handleDropOnView( QDropEvent * ) ) );
+
+#ifdef TESTING_BRIEF_VIEW // code is used for testing purposes only! do not enable it!!! 
+	view = new KrBriefView( splt, _left, krConfig );
+   view->init();
+/* TODO
    connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( middleButtonClicked( QListViewItem * ) ), SLOTS, SLOT( newTab( QListViewItem * ) ) );
 	connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( currentChanged( QListViewItem* ) ), 
 		SLOTS, SLOT( updatePopupPanel( QListViewItem* ) ) );
+
+	// connect quicksearch
+   connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& ) ) );
+   connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
+   connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
+   connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );	
+*/
+#else	
+   view = new KrDetailedView( splt, _left, krConfig );
+   view->init();
+   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( middleButtonClicked( QListViewItem * ) ), SLOTS, SLOT( newTab( QListViewItem * ) ) );
+	connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( currentChanged( QListViewItem* ) ), 
+		SLOTS, SLOT( updatePopupPanel( QListViewItem* ) ) );
+	// connect quicksearch
+   connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& ) ) );
+   connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
+   connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
+   connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
+            dynamic_cast<KrDetailedView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );
+#endif
+
+   connect( view->op(), SIGNAL( renameItem( const QString &, const QString & ) ),
+            func, SLOT( rename( const QString &, const QString & ) ) );
+   connect( view->op(), SIGNAL( executed( QString& ) ), func, SLOT( execute( QString& ) ) );
+   connect( view->op(), SIGNAL( needFocus() ), this, SLOT( slotFocusOnMe() ) );
+   connect( view->op(), SIGNAL( selectionChanged() ), this, SLOT( slotUpdateTotals() ) );
+   connect( view->op(), SIGNAL( itemDescription( QString& ) ), krApp, SLOT( statusBarUpdate( QString& ) ) );
+   connect( view->op(), SIGNAL( contextMenu( const QPoint & ) ), this, SLOT( popRightClickMenu( const QPoint & ) ) );
+   connect( view->op(), SIGNAL( emptyContextMenu( const QPoint &) ), 
+   	this, SLOT( popEmptyRightClickMenu( const QPoint & ) ) );
+   connect( view->op(), SIGNAL( letsDrag( QStringList, QPixmap ) ), this, SLOT( startDragging( QStringList, QPixmap ) ) );
+   connect( view->op(), SIGNAL( gotDrop( QDropEvent * ) ), this, SLOT( handleDropOnView( QDropEvent * ) ) );
    // make sure that a focus/path change reflects in the command line and activePanel
    connect( this, SIGNAL( cmdLineUpdate( QString ) ), SLOTS, SLOT( slotCurrentChanged( QString ) ) );
    connect( this, SIGNAL( activePanelChanged( ListPanel * ) ), SLOTS, SLOT( slotSetActivePanel( ListPanel * ) ) );
@@ -429,7 +485,7 @@ void ListPanel::compareDirs() {
            
       bool isSingle = ( otherItem == 0 ), isDifferent = false, isNewer = false;
    
-      if( item->isDir() && !selectDirs )
+      if( func->getVFile(item)->vfile_isDir() && !selectDirs )
       {
          item->setSelected( false );
          continue;
@@ -437,9 +493,9 @@ void ListPanel::compareDirs() {
       
       if( otherItem )
       {
-         if( !item->isDir() )
-            isDifferent = otherItem->size() != item->size();
-         isNewer = item->getTime_t() > otherItem->getTime_t();
+         if( !func->getVFile(item)->vfile_isDir() )
+            isDifferent = ITEM2VFILE(otherPanel,otherItem)->vfile_getSize() != func->getVFile(item)->vfile_getSize();
+         isNewer = func->getVFile(item)->vfile_getTime_t() > ITEM2VFILE(otherPanel, otherItem)->vfile_getTime_t();
       }
 
       switch( compareMode )
@@ -502,32 +558,9 @@ void ListPanel::slotFocusOnMe() {
 // this is used to start the panel, AFTER setOther() has been used
 //////////////////////////////////////////////////////////////////
 void ListPanel::start( KURL url, bool immediate ) {
-   bool left = _left;
    KURL virt;
-	krConfig->setGroup( "Startup" );
-
-   // set the startup path
-   if ( !url.isEmpty() ) {
-      virt = url;
-   } else
-      if ( left ) {
-         if ( krConfig->readEntry( "Left Panel Origin", _LeftPanelOrigin ) == i18n( "homepage" ) )
-            virt = URL(krConfig->readEntry( "Left Panel Homepage", _LeftHomepage ));
-         else if ( krConfig->readEntry( "Left Panel Origin" ) == i18n( "the last place it was" ) )
-            // read the first of the tabbar. lastHomeLeft is obsolete!
-            virt = URL((krConfig->readPathListEntry( "Left Tab Bar" ))[0]);
-         else
-            virt = URL(getcwd( 0, 0 )); //get_current_dir_name();
-      } else { // right
-         if ( krConfig->readEntry( "Right Panel Origin", _RightPanelOrigin ) == i18n( "homepage" ) )
-            virt = URL(krConfig->readEntry( "Right Panel Homepage", _RightHomepage ));
-         else if ( krConfig->readEntry( "Right Panel Origin" ) == i18n( "the last place it was" ) )
-            // read the first of the tabbar. lastHomeLeft is obsolete!
-            virt = URL((krConfig->readPathListEntry( "Right Tab Bar" ))[0]);
-         else
-            virt = URL(getcwd( 0, 0 ));
-      }
-
+   
+   virt = url;
    
    if ( !virt.isValid() )
       virt = URL("/");
@@ -538,6 +571,8 @@ void ListPanel::start( KURL url, bool immediate ) {
      func->immediateOpenUrl( virt );
    else
      func->openUrl( virt );
+
+   setJumpBack( virt );
 }
 
 void ListPanel::slotStartUpdate() {
@@ -546,6 +581,11 @@ void ListPanel::slotStartUpdate() {
    func->inRefresh = true;  // make sure the next refresh wait for this one
 	if (inlineRefreshJob)
 		inlineRefreshListResult(0);
+
+	if( this == ACTIVE_PANEL ){
+		slotFocusOnMe();
+	}
+
    setCursor( KCursor::workingCursor() );
    view->clear();
 
@@ -755,292 +795,13 @@ void ListPanel::startDragging( QStringList names, QPixmap px ) {
 
 // pops a right-click menu for items
 void ListPanel::popRightClickMenu( const QPoint &loc ) {
-   // these are the values that will always exist in the menu
-#define OPEN_TAB_ID   150089
-#define OPEN_ID       150090
-#define OPEN_WITH_ID  150091
-#define OPEN_KONQ_ID  150092
-#define OPEN_TERM_ID  150093
-#define KONQ_MENU_ID  150094
-#define CHOOSE_ID     150095
-#define DELETE_ID     150096
-#define COPY_ID       150097
-#define MOVE_ID       150098
-#define RENAME_ID     150099
-#define PROPERTIES_ID 150100
-#define MOUNT_ID      150101
-#define UNMOUNT_ID    150102
-#define SHRED_ID      150103
-#define NEW_LINK      150104
-#define NEW_SYMLINK   150105
-#define REDIRECT_LINK 150106
-#define SEND_BY_EMAIL 150107
-#define LINK_HANDLING 150108
-#define EJECT_ID      150109
-#define PREVIEW_ID    150110
-#define COPY_CLIP_ID  150111
-#define MOVE_CLIP_ID  150112
-#define PASTE_CLIP_ID 150113
-
-   // those will sometimes appear
-#define SERVICE_LIST_ID  150200
-   //////////////////////////////////////////////////////////
-   bool multipleSelections = false;
-   // a quick hack to check if we've got more that one file selected
-   KrViewItemList items;
-   view->getSelectedKrViewItems( &items );
-   if ( items.empty() )
-      return ;
-   if ( items.size() > 1 )
-      multipleSelections = true;
-   KrViewItem *item = items.first();
-   // create the menu
-   KPopupMenu popup, openWith, linkPopup;
-   // the OPEN option - open preferd service
-   popup.insertItem( "Open/Run", OPEN_ID );      // create the open option
-   if ( !multipleSelections ) { // meaningful only if one file is selected
-      popup.changeItem( OPEN_ID, item->icon(),        // and add pixmap
-                        i18n( ( item->isExecutable() ) && ( !item->isDir() ) ? "Run" : "Open" ) );
-      // open in a new tab (if folder)
-      if ( item->isDir() ) {
-         popup.insertItem( i18n( "Open in a new tab" ), OPEN_TAB_ID );
-         popup.changeItem( OPEN_TAB_ID, krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in a new tab" ) );
-      }
-      popup.insertSeparator();
-   }
-   // Preview - normal vfs only ?
-   KrPreviewPopup preview;
-   if ( func->files() ->vfs_getType() == vfs::NORMAL ) {
-      // create the preview popup
-      QStringList names;
-      getSelectedNames( &names );
-      preview.setUrls( func->files() ->vfs_getFiles( &names ) );
-      popup.insertItem( QPixmap(), &preview, PREVIEW_ID );
-      popup.changeItem( PREVIEW_ID, i18n( "Preview" ) );
-   }
-   // Open with
-   // try to find-out which apps can open the file
-   OfferList offers;
-   // this too, is meaningful only if one file is selected or if all the files
-   // have the same mimetype !
-   QString mime = item->mime();
-   // check if all the list have the same mimetype
-   for ( unsigned int i = 1; i < items.size(); ++i ) {
-      if ( ( *items.at( i ) ) ->mime() != mime ) {
-         mime = QString::null;
-         break;
-      }
-   }
-   if ( !mime.isEmpty() ) {
-      offers = KServiceTypeProfile::offers( mime );
-      for ( unsigned int i = 0; i < offers.count(); ++i ) {
-         KService::Ptr service = offers[ i ].service();
-         if ( service->isValid() && service->type() == "Application" ) {
-            openWith.insertItem( service->name(), SERVICE_LIST_ID + i );
-            openWith.changeItem( SERVICE_LIST_ID + i, service->pixmap( KIcon::Small ), service->name() );
-         }
-      }
-      openWith.insertSeparator();
-      if ( item->isDir() )
-         openWith.insertItem( krLoader->loadIcon( "konsole", KIcon::Small ), i18n( "Terminal" ), OPEN_TERM_ID );
-      openWith.insertItem( i18n( "Other..." ), CHOOSE_ID );
-      popup.insertItem( QPixmap(), &openWith, OPEN_WITH_ID );
-      popup.changeItem( OPEN_WITH_ID, i18n( "Open with" ) );
-      popup.insertSeparator();
-   }
-   
-   popup.insertItem( i18n("User Actions"), new UserActionPopupMenu( func->files()->vfs_getFile( item->name() ).url() ) );
-   
-   KFileItemList _items;
-   _items.setAutoDelete( true );
-   for ( KrViewItemList::Iterator it = items.begin(); it != items.end(); ++it ) 
-   {
-     vfile *file = func->files() ->vfs_search( ( *it )->name() );
-     KURL url = func->files() ->vfs_getFile( ( *it )->name() );
-     _items.append( new KFileItem( url,  file->vfile_getMime(), file->vfile_getMode() ) );
-   }
-   
-#ifdef __LIBKONQ__
-   KActionCollection actions(this);
-   KonqPopupMenu konqMenu( KonqBookmarkManager::self(), _items, func->files()->vfs_getOrigin(), actions, 0, this, 
-                           KonqPopupMenu::ShowProperties, KParts::BrowserExtension::DefaultPopupItems );
-   popup.insertItem( QPixmap(), &konqMenu, KONQ_MENU_ID );
-   popup.changeItem( KONQ_MENU_ID, i18n( "Konqueror menu" ) );
-   popup.insertSeparator();
-#endif
-      
-   // COPY
-   popup.insertItem( i18n( "Copy" ), COPY_ID );
-   if ( func->files() ->vfs_isWritable() ) {
-      // MOVE
-      popup.insertItem( i18n( "Move" ), MOVE_ID );
-      // RENAME - only one file
-      if ( !multipleSelections )
-         popup.insertItem( i18n( "Rename" ), RENAME_ID );
-      // DELETE
-      popup.insertItem( i18n( "Delete" ), DELETE_ID );
-      // SHRED - only one file
-      if ( func->files() ->vfs_getType() == vfs::NORMAL &&
-            !item->isDir() && !multipleSelections )
-         popup.insertItem( i18n( "Shred" ), SHRED_ID );
-   }
-   // create new shortcut or redirect links - only on local directories:
-   if ( func->files() ->vfs_getType() == vfs::NORMAL ) {
-      popup.insertSeparator();
-      linkPopup.insertItem( i18n( "new symlink" ), NEW_SYMLINK );
-      linkPopup.insertItem( i18n( "new hardlink" ), NEW_LINK );
-      if ( item->isSymLink() )
-         linkPopup.insertItem( i18n( "redirect link" ), REDIRECT_LINK );
-      popup.insertItem( QPixmap(), &linkPopup, LINK_HANDLING );
-      popup.changeItem( LINK_HANDLING, i18n( "Link handling" ) );
-   }
-   popup.insertSeparator();
-   if ( func->files() ->vfs_getType() == vfs::NORMAL && ( item->isDir() || multipleSelections ) )
-      krCalculate->plug( &popup );
-   if ( func->files() ->vfs_getType() == vfs::NORMAL && item->isDir() && !multipleSelections ) {
-      if ( krMtMan.getStatus( func->files() ->vfs_getFile( item->name() ).path( -1 ) ) == KMountMan::MOUNTED )
-         popup.insertItem( i18n( "Unmount" ), UNMOUNT_ID );
-      else if ( krMtMan.getStatus( func->files() ->vfs_getFile( item->name() ).path( -1 ) ) == KMountMan::NOT_MOUNTED )
-         popup.insertItem( i18n( "Mount" ), MOUNT_ID );
-      if ( krMtMan.ejectable( func->files() ->vfs_getFile( item->name() ).path( -1 ) ) )
-         popup.insertItem( i18n( "Eject" ), EJECT_ID );
-   }
-   // send by mail (only for KDE version >= 2.2.0)
-   if ( Krusader::supportedTools().contains( "MAIL" ) && !item->isDir() ) {
-      popup.insertItem( i18n( "Send by email" ), SEND_BY_EMAIL );
-   }
-   // PROPERTIES
-   popup.insertSeparator();
-   popup.insertItem( i18n( "Copy to Clipboard" ), COPY_CLIP_ID );
-   if ( func->files() ->vfs_isWritable() )
-   {
-     popup.insertItem( i18n( "Cut to Clipboard" ), MOVE_CLIP_ID );
-     popup.insertItem( i18n( "Paste from Clipboard" ), PASTE_CLIP_ID );
-   }
-   popup.insertSeparator();
-   krProperties->plug( &popup );
    // run it, on the mouse location
-   int j = QFontMetrics( popup.font() ).height() * 2;
-   int result = popup.exec( QPoint( loc.x() + 5, loc.y() + j ) );
-   // check out the user's option
-   KURL u;
-   KURL::List lst;
-
-   switch ( result ) {
-         case - 1 :
-         return ;     // the user clicked outside of the menu
-         case OPEN_TAB_ID :               // Open/Run
-         // assuming only 1 file is selected (otherwise we won't get here)
-         ( ACTIVE_PANEL == LEFT_PANEL ? krApp->mainView->leftMng :
-           krApp->mainView->rightMng ) ->slotNewTab( func->files() ->vfs_getFile( item->name() ).url() );
-         break;
-         case OPEN_ID :               // Open in a new tab
-         for ( KrViewItemList::Iterator it = items.begin(); it != items.end(); ++it ) {
-            u = func->files() ->vfs_getFile( ( *it ) ->name() );
-            KRun::runURL( u, item->mime() );
-         }
-         break;
-         case COPY_ID :
-         func->copyFiles();
-         break;
-         case MOVE_ID :
-         func->moveFiles();
-         break;
-         case RENAME_ID :
-         SLOTS->rename();
-         break;
-         case DELETE_ID :
-         func->deleteFiles();
-         break;
-         case EJECT_ID :
-         KMountMan::eject( func->files() ->vfs_getFile( item->name() ).path( -1 ) );
-         break;
-         case SHRED_ID :
-         if ( KMessageBox::warningContinueCancel( krApp,
-               i18n( "Are you sure you want to shred " ) + "\"" + item->name() + "\"" +
-               i18n(" ? Once shred, the file is gone forever !!!"),
-               QString::null, KStdGuiItem::cont(), "Shred" ) == KMessageBox::Continue )
-            KShred::shred( func->files() ->vfs_getFile( item->name() ).path( -1 ) );
-         break;
-         case OPEN_KONQ_ID :          // open in konqueror
-         kapp->startServiceByDesktopName( "konqueror", func->files() ->vfs_getFile( item->name() ).url() );
-         break;
-         case CHOOSE_ID :             // Other...
-         u = func->files() ->vfs_getFile( item->name() );
-         lst.append( u );
-         KRun::displayOpenWithDialog( lst );
-         break;
-         case MOUNT_ID :
-         krMtMan.mount( func->files() ->vfs_getFile( item->name() ).path( -1 ) );
-         break;
-         case NEW_LINK :
-         func->krlink( false );
-         break;
-         case NEW_SYMLINK :
-         func->krlink( true );
-         break;
-         case REDIRECT_LINK :
-         func->redirectLink();
-         break;
-         case UNMOUNT_ID :
-         krMtMan.unmount( func->files() ->vfs_getFile( item->name() ).path( -1 ) );
-         break;
-         case COPY_CLIP_ID :
-         func->copyToClipboard();
-         break;
-         case MOVE_CLIP_ID :
-         func->copyToClipboard( true );
-         break;
-         case PASTE_CLIP_ID :
-         func->pasteFromClipboard();
-         break;
-         case SEND_BY_EMAIL :
-         SLOTS->sendFileByEmail( func->files() ->vfs_getFile( item->name() ).url() );
-         break;
-         case OPEN_TERM_ID :          // open in terminal
-         QString save = getcwd( 0, 0 );
-         chdir( func->files() ->vfs_getFile( item->name() ).path( -1 ).local8Bit() );
-         KProcess proc;
-         krConfig->setGroup( "General" );
-         QString term = krConfig->readEntry( "Terminal", _Terminal );
-         proc << KrServices::separateArgs( term );
-         if ( !item->isDir() )
-            proc << "-e" << item->name();
-
-         if ( term.contains( "konsole" ) )     /* KDE 3.2 bug (konsole is killed by pressing Ctrl+C) */
-         {                                  /* Please remove the patch if the bug is corrected */
-            proc << "&";
-            proc.setUseShell( true );
-         }
-
-         if ( !proc.start( KProcess::DontCare ) )
-            KMessageBox::sorry( krApp, i18n( "Can't open " ) + "\"" + term + "\"" );
-         chdir( save.local8Bit() );
-         break;
-   }
-   if ( result >= SERVICE_LIST_ID ) {
-      QStringList names;
-      getSelectedNames( &names );
-      KRun::run( *( offers[ result - SERVICE_LIST_ID ].service() ),
-                 *( func->files() ->vfs_getFiles( &names ) ) );
-   }
+   int j = QFontMetrics( font() ).height() * 2;
+   KrPopupMenu::run(QPoint( loc.x() + 5, loc.y() + j ), this);
 }
 
-void ListPanel::popEmptyRightClickMenu( QListViewItem *item, const QPoint &loc, int ) {
-   if( item == 0 )
-   {
-      KPopupMenu popup;
-   
-      popup.insertItem( i18n( "Paste from Clipboard" ), PASTE_CLIP_ID );
-   
-      int result = popup.exec( loc );
-      switch ( result ) 
-      {
-         case PASTE_CLIP_ID :
-         func->pasteFromClipboard();
-         break;
-      }
-   }
+void ListPanel::popEmptyRightClickMenu( const QPoint &loc ) {
+	KrPopupMenu::run(loc, this);
 }
 
 void ListPanel::setFilter( KrViewProperties::FilterSpec f ) {
@@ -1080,8 +841,13 @@ void ListPanel::keyPressEvent( QKeyEvent *e ) {
          case Key_Enter :
          case Key_Return :
          if ( e->state() & ControlButton ) {
-            SLOTS->insertFileName( ( e->state() & ShiftButton ) != 0 );
-            MAIN_VIEW->cmdLine->setFocus();
+         	if (e->state() & AltButton) {
+         		vfile *vf = func->files()->vfs_search(view->getCurrentKrViewItem()->name());
+         		if (vf && vf->vfile_isDir()) SLOTS->newTab(vf->vfile_getUrl());
+         	} else {
+					SLOTS->insertFileName( ( e->state() & ShiftButton ) != 0 );
+					MAIN_VIEW->cmdLine->setFocus();
+            }
          } else e->ignore();
          break;
          case Key_Right :
@@ -1091,19 +857,21 @@ void ListPanel::keyPressEvent( QKeyEvent *e ) {
             // directory otherwise as this one
             if ( ( _left && e->key() == Key_Right ) || ( !_left && e->key() == Key_Left ) ) {
                KURL newPath;
-               if ( view->getCurrentKrViewItem() ->isDir() ) {
-                  newPath = func->files() ->vfs_getFile( view->getCurrentKrViewItem() ->name() );
+               KrViewItem *it = view->getCurrentKrViewItem();
+
+               if( it->name() == ".." ) {
+                  newPath = func->files()->vfs_getOrigin().upURL();
                } else {
-                  newPath = func->files() ->vfs_getOrigin();
+                  vfile *v = func->getVFile( it );
+                  if ( v && v->vfile_isDir() && v->vfile_getName() != ".." ) {
+                     newPath = v->vfile_getUrl();
+                  } else {
+                     newPath = func->files() ->vfs_getOrigin();
+                  }
                }
                otherPanel->func->openUrl( newPath );
-            } else
-               func->openUrl( otherPanel->func->files() ->vfs_getOrigin() );
-
-            slotFocusOnMe(); // return focus to us!
+            } else func->openUrl( otherPanel->func->files() ->vfs_getOrigin() );
             return ;
-            //} else if (e->state() == ShiftButton) {
-            //	krApp->mainView->leftMng->changePanel(e->key() == Key_Left);
          } else
             e->ignore();
          break;
@@ -1120,10 +888,6 @@ void ListPanel::keyPressEvent( QKeyEvent *e ) {
          break;
 
 			case Key_Up :
-			if (e->state() == ControlButton) { // jump to the origin bar
-				origin->lineEdit()->selectAll();
-				origin->setFocus();
-			}
 			break;
 
          default:
@@ -1148,6 +912,10 @@ void ListPanel::slotItemUpdated(vfile *vf) {
 	view->updateItem(vf);
 }
 
+void ListPanel::slotCleared() {
+	view->clear();
+}
+
 void ListPanel::showEvent( QShowEvent *e ) {
   panelActive();
   QWidget::showEvent(e);
@@ -1233,4 +1001,12 @@ void ListPanel::inlineRefreshListResult(KIO::Job*) {
 	inlineRefreshCancelButton->hide();
 }
 
+void ListPanel::jumpBack() {
+	func->openUrl( _jumpBackURL );
+}
+
+void ListPanel::setJumpBack( KURL url ) {
+	_jumpBackURL = url;
+}
+
 #include "listpanel.moc"
