@@ -50,6 +50,8 @@ A
 #include <kstandarddirs.h>
 #include <ktempdir.h> 
 #include <kurlrequester.h>
+#include <kprocio.h>
+#include <kdesktopfile.h>
 // Krusader Includes
 #include "panelfunc.h"
 #include "krcalcspacedialog.h"
@@ -63,10 +65,12 @@ A
 #include "../VFS/krarchandler.h"
 #include "../VFS/krpermhandler.h"
 #include "../VFS/krvfshandler.h"
+#include "../VFS/preservingcopyjob.h"
 #include "../Dialogs/packgui.h"
 #include "../Dialogs/krdialogs.h"
 #include "../Dialogs/krpleasewait.h"
 #include "../Dialogs/krspwidgets.h"
+#include "../Dialogs/checksumdlg.h"
 #include "../KViewer/krviewer.h"
 #include "../resources.h"
 #include "../krservices.h"
@@ -96,7 +100,7 @@ void ListPanelFunc::openUrl( const QString& url, const QString& nameToMakeCurren
 void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	KURL url = urlIn;
 	url.cleanPath();
-	
+
 	// check for special cases first - don't refresh here !
 	// you may call openUrl or vfs_refresh()
 	if ( !url.isValid() ) {
@@ -116,15 +120,22 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	panel->slotFocusOnMe();
 
 	// if we are not refreshing to current URL
-	if ( !files() ->vfs_getOrigin().equals( url, true ) ) {
+	bool is_equal_url = files() ->vfs_getOrigin().equals( url, true );
+	
+	if ( !is_equal_url ) {
 		// change the cursor to busy
 		panel->setCursor( KCursor::waitCursor() );
-		// clear the view - to avoid a repaint crash
-		panel->view->clear();
 	}
 
 	if ( !nameToMakeCurrent.isEmpty() ) {
 		panel->view->setNameToMakeCurrent( nameToMakeCurrent );
+		// if the url we're refreshing into is the current one, then the
+		// partial url will not generate the needed signals to actually allow the
+		// view to use nameToMakeCurrent. do it here instead (patch by Thomas Jarosch)
+		if ( is_equal_url ) {
+		    panel->view->setCurrentItem( nameToMakeCurrent );
+		    panel->view->makeItemVisible( panel->view->getCurrentKrViewItem() );
+		}		
 	}
 
 	vfs* v = 0;
@@ -138,14 +149,23 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 		if ( !v )
 			continue; //this should not happen !
 		if ( v != vfsP ) {
-			vfsP->deleteLater();
+			if( vfsP->vfs_canDelete() )                
+				delete vfsP;
+			else {
+				connect( vfsP, SIGNAL( deleteAllowed() ), vfsP, SLOT( deleteLater() ) );
+				vfsP->vfs_requestDelete();                                
+			}
 			vfsP = v; // v != 0 so this is safe
 		}
 		connect( files(), SIGNAL(startJob(KIO::Job* )),
 				panel, SLOT(slotJobStarted(KIO::Job* )));
 		if ( vfsP->vfs_refresh( u ) )
 			break; // we have a valid refreshed URL now
+		if ( vfsP == 0 )  // the object was deleted during vfs_refresh? Hoping the best...
+			return;                
 		// prevent repeated error messages
+		if ( vfsP->vfs_isDeleting() )
+			break;                
 		vfsP->vfs_setQuiet( true );
 	}
 	vfsP->vfs_setQuiet( false );
@@ -158,6 +178,7 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	disconnect( files(), SIGNAL( addedVfile( vfile* ) ), 0, 0 );
 	disconnect( files(), SIGNAL( updatedVfile( vfile* ) ), 0, 0 );
 	disconnect( files(), SIGNAL( deletedVfile( const QString& ) ), 0, 0 );
+	disconnect( files(), SIGNAL( cleared() ), 0, 0 );
 	// connect to the vfs's dirwatch signals
 	connect( files(), SIGNAL( addedVfile( vfile* ) ),
 	         panel, SLOT( slotItemAdded( vfile* ) ) );
@@ -165,6 +186,8 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	         panel, SLOT( slotItemUpdated( vfile* ) ) );
 	connect( files(), SIGNAL( deletedVfile( const QString& ) ),
 	         panel, SLOT( slotItemDeleted( const QString& ) ) );
+	connect( files(), SIGNAL( cleared() ),
+	         panel, SLOT( slotCleared() ) );
 	
 	// on local file system change the working directory
 	if ( files() ->vfs_getType() == vfs::NORMAL )
@@ -355,6 +378,8 @@ void ListPanelFunc::editFile() {
 }
 
 void ListPanelFunc::moveFiles() {
+	PreserveMode pmode = PM_DEFAULT;
+
 	QStringList fileNames;
 	panel->getSelectedNames( &fileNames );
 	if ( fileNames.isEmpty() )
@@ -370,15 +395,21 @@ void ListPanelFunc::moveFiles() {
 
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Move", _ConfirmMove ) ) {
+		bool preserveDate = krConfig->readBoolEntry( "PreserveDate", _PreserveDate );
 		QString s;
-		if ( fileNames.count() == 1 )
-			s = i18n( "Move " ) + fileNames.first() + " " + i18n( "to" ) + ":";
-		else
-			s.sprintf( i18n( "Move %d files to:" ).local8Bit(), fileNames.count() );
+
+  if( fileNames.count() == 1 )
+    s = i18n("Move %1 to:").arg(fileNames.first());
+  else
+    s = i18n("Move %n file to:", "Move %n files to:", fileNames.count());
 
 		// ask the user for the copy dest
-		dest = KChooseDir::getDir(s, dest, panel->virtualPath());
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveDate);
 		if ( dest.isEmpty() ) return ; // the user canceled
+		if( preserveDate )
+			pmode = PM_PRESERVE_DATE;
+		else
+			pmode = PM_NONE;
 	}
 
 	if ( fileNames.isEmpty() )
@@ -395,7 +426,7 @@ void ListPanelFunc::moveFiles() {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
 		if ( fileNames.count() > 1 ) dest.adjustPath(1);
-		KIO::Job* job = new KIO::CopyJob( *fileUrls, dest, KIO::CopyJob::Move, false, true );
+		KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, KIO::CopyJob::Move, false, true );
 		job->setAutoErrorHandlingEnabled( true );
 		// refresh our panel when done
 		connect( job, SIGNAL( result( KIO::Job* ) ), this, SLOT( refresh() ) );
@@ -410,7 +441,7 @@ void ListPanelFunc::moveFiles() {
 			return ;
 		}
 		// finally..
-		otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Move, files() );
+		otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Move, files(), "", pmode );
 	}
 }
 
@@ -423,7 +454,7 @@ void ListPanelFunc::rename() {
 void ListPanelFunc::rename( const QString &oldname, const QString &newname ) {
 	if ( oldname == newname )
 		return ; // do nothing
-	panel->view->setNameToMakeCurrent( newname );
+	panel->view->setNameToMakeCurrentIfAdded( newname );
 	// as always - the vfs do the job
 	files() ->vfs_rename( oldname, newname );
 }
@@ -464,6 +495,8 @@ void ListPanelFunc::mkdir() {
 }
 
 void ListPanelFunc::copyFiles() {
+	PreserveMode pmode = PM_DEFAULT;
+
 	QStringList fileNames;
 	panel->getSelectedNames( &fileNames );
 	if ( fileNames.isEmpty() )
@@ -474,14 +507,21 @@ void ListPanelFunc::copyFiles() {
 	// confirm copy
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Copy", _ConfirmCopy ) ) {
+		bool preserveDate = krConfig->readBoolEntry( "PreserveDate", _PreserveDate );
 		QString s;
-		if ( fileNames.count() == 1 )
-			s = i18n( "Copy " ) + fileNames.first() + " " + i18n( "to" ) + ":";
-		else
-			s.sprintf( i18n( "Copy %d files to:" ).local8Bit(), fileNames.count() );
+
+  if( fileNames.count() == 1 )
+    s = i18n("Copy %1 to:").arg(fileNames.first());
+  else
+    s = i18n("Copy %n file to:", "Copy %n files to:", fileNames.count());
+
 		// ask the user for the copy dest
-		dest = KChooseDir::getDir(s, dest, panel->virtualPath());
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveDate );
 		if ( dest.isEmpty() ) return ; // the user canceled
+		if( preserveDate )
+			pmode = PM_PRESERVE_DATE;
+		else
+			pmode = PM_NONE;
 	}
 
 	KURL::List* fileUrls = files() ->vfs_getFiles( &fileNames );
@@ -491,7 +531,7 @@ void ListPanelFunc::copyFiles() {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
 		if ( fileNames.count() > 1 ) dest.adjustPath(1);
-		KIO::Job* job = new KIO::CopyJob( *fileUrls, dest, KIO::CopyJob::Copy, false, true );
+		KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls, dest, KIO::CopyJob::Copy, false, true );
 		job->setAutoErrorHandlingEnabled( true );
 		if ( dest.equals( panel->virtualPath(), true ) ||
 			dest.upURL().equals( panel->virtualPath(), true ) )
@@ -505,7 +545,7 @@ void ListPanelFunc::copyFiles() {
 			return ;
 		}
 		// finally..
-		otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Copy, 0 );
+		otherFunc() ->files() ->vfs_addFiles( fileUrls, KIO::CopyJob::Copy, 0, "", pmode );
 	}
 }
 
@@ -528,22 +568,19 @@ void ListPanelFunc::deleteFiles(bool reallyDelete) {
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Delete", _ConfirmDelete ) ) {
 		QString s, b;
-		if ( fileNames.count() == 1 )
-			s = i18n( " this item?" );
-		else
-			s.sprintf( i18n( " these %d items?" ).local8Bit(), fileNames.count() );
-		
+
 		if ( !reallyDelete && trash && files() ->vfs_getType() == vfs::NORMAL ) {
-			s = i18n( "trash" ) + s;
+			s = i18n( "Do you really want to move this item to the trash?", "Do you really want to move these %n items to the trash?", fileNames.count() );
 			b = i18n( "&Trash" );
 		} else {
-			s = i18n( "delete" ) + s;
+			s = i18n( "Do you really want to delete this item?", "Do you really want to delete these %n items?", fileNames.count() );
 			b = i18n( "&Delete" );
 		}
+
 		// show message
 		// note: i'm using continue and not yes/no because the yes/no has cancel as default button
-		if ( KMessageBox::warningContinueCancelList( krApp, i18n( "Are you sure you want to " ) + s
-		                                             , fileNames, i18n( "Warning" ), b ) != KMessageBox::Continue )
+		if ( KMessageBox::warningContinueCancelList( krApp, s, fileNames,
+                                                     i18n( "Warning" ), b ) != KMessageBox::Continue )
 			return ;
 	}
 	//we want to warn the user about non empty dir
@@ -559,7 +596,7 @@ void ListPanelFunc::deleteFiles(bool reallyDelete) {
 		// verify non-empty dirs delete... (only for normal vfs)
 		if ( emptyDirVerify && vf->vfile_isDir() && !vf->vfile_isSymLink() ) {
 			dir.setPath( panel->virtualPath().path() + "/" + ( *name ) );
-			if ( dir.count() > 2 ) {
+			if ( dir.entryList(QDir::All | QDir::AccessMask).count() > 2 ) {
 				switch ( KMessageBox::warningYesNoCancel( krApp,
 				                                          i18n( "Directory " ) + ( *name ) + i18n( " is not empty!\nSkip this one or Delete All?" ),
 				                                          QString::null, i18n( "&Skip" ), i18n( "&Delete All" ) ) ) {
@@ -630,7 +667,8 @@ void ListPanelFunc::execute( QString& name ) {
 		openUrl( path );
 	} else {
 		KURL url = files() ->vfs_getFile( name );
-		KRun::runURL( url, vf->vfile_getMime() );
+		KFileItem kfi( vf->vfile_getEntry(), url,true );
+		kfi.run();	
 	}
 }
 
@@ -671,6 +709,10 @@ void ListPanelFunc::pack() {
 	QString arcFile;
 	if ( destURL.isLocalFile() )
 		arcFile = destURL.path();
+	else if( destURL.protocol() == "virt" ) {
+		KMessageBox::error( krApp, i18n( "Cannot pack files onto a virtual destination!" ) );
+		return;                
+	}        
 	else {
 		tempDestFile = new KTempFile( QString::null, "." + PackGUI::type );
 		tempDestFile->setAutoDelete( true );
@@ -699,10 +741,8 @@ void ListPanelFunc::pack() {
 
 	KIO::filesize_t totalSize = 0;
 	unsigned long totalDirs = 0, totalFiles = 0;
-	for ( QStringList::Iterator file = fileNames.begin(); file != fileNames.end(); ++file ) {
-		bool stop = false;
-		files() ->vfs_calcSpace( ( *file ), &totalSize, &totalFiles, &totalDirs, &stop );
-	}
+	if( !calcSpace( fileNames, totalSize, totalFiles, totalDirs ) )
+		return;
 
 	// download remote URL-s if necessary
 	QString arcDir;
@@ -786,10 +826,10 @@ void ListPanelFunc::unpack() {
 		return ;  // safety
 
 	QString s;
-	if ( fileNames.count() == 1 )
-		s = i18n( "Unpack " ) + fileNames[ 0 ] + " " + i18n( "to" ) + ":";
-	else
-		s = i18n( "Unpack " ) + i18n( "%1 files" ).arg( fileNames.count() ) + i18n( "to" ) + ":";
+  if(fileNames.count() == 1)
+    s = i18n("Unpack %1 to:").arg(fileNames[0]);
+  else
+    s = i18n("Unpack %n file to:", "Unpack %n files to:", fileNames.count());
 
 	// ask the user for the copy dest
 	KURL dest = KChooseDir::getDir(s, panel->otherPanel->virtualPath(), panel->virtualPath());
@@ -862,6 +902,40 @@ void ListPanelFunc::unpack() {
 		panel->otherPanel->func->refresh();
 }
 
+// a small ugly function, used to prevent duplication of EVERY line of
+// code (maybe except 3) from createChecksum and matchChecksum
+static void checksum_wrapper(ListPanel *panel, QStringList& args, bool &folders) {
+	KrViewItemList items;
+	panel->view->getSelectedKrViewItems( &items );
+	if ( items.isEmpty() ) return ; // nothing to do
+	// determine if we need recursive mode (md5deep)
+	folders=false;
+	for ( KrViewItemList::Iterator it = items.begin(); it != items.end(); ++it ) {
+		if (panel->func->getVFile(*it)->vfile_isDir()) {
+			folders = true;
+			args << (*it)->name();
+		} else args << (*it)->name();
+	}
+}
+
+void ListPanelFunc::createChecksum() {
+	QStringList args;
+	bool folders;
+	checksum_wrapper(panel, args, folders);
+	CreateChecksumDlg dlg(args, folders, panel->realPath());
+}
+
+void ListPanelFunc::matchChecksum() {
+	QStringList args;
+	bool folders;
+	checksum_wrapper(panel, args, folders);
+	QValueList<vfile*> checksumFiles = files()->vfs_search(
+		KRQuery(MatchChecksumDlg::checksumTypesFilter)
+	);
+	MatchChecksumDlg dlg(args, folders, panel->realPath(), 
+		(checksumFiles.size()==1 ? checksumFiles[0]->vfile_getUrl().prettyURL() : QString::null));
+}
+
 void ListPanelFunc::calcSpace() {
 	QStringList items;
 	panel->view->getSelectedItems( &items );
@@ -874,13 +948,10 @@ void ListPanelFunc::calcSpace() {
 
 	KrCalcSpaceDialog calc( krApp, panel, items, false );
 	calc.exec();
-	KrDetailedView * view = dynamic_cast<KrDetailedView *> ( panel->view );
-	if ( !view )
-		return ;
 	for ( QStringList::ConstIterator it = items.begin(); it != items.end(); ++it ) {
-		KrDetailedViewItem * viewItem = dynamic_cast<KrDetailedViewItem *> ( view->findItemByName( *it ) );
+		KrViewItem *viewItem = panel->view->findItemByName( *it );
 		if ( viewItem )
-			viewItem->repaintItem();
+			panel->view->updateItem(viewItem);
 	}
 	panel->slotUpdateTotals();
 }
@@ -939,10 +1010,12 @@ void ListPanelFunc::properties() {
 
 void ListPanelFunc::refreshActions() {
 	vfs::VFS_TYPE vfsType = files() ->vfs_getType();
+
 	//  set up actions
 	krMultiRename->setEnabled( vfsType == vfs::NORMAL );  // batch rename
 	//krProperties ->setEnabled( vfsType == vfs::NORMAL || vfsType == vfs::FTP ); // file properties
 	krFTPDiss ->setEnabled( vfsType == vfs::FTP );     // disconnect an FTP session
+	krCreateCS->setEnabled( vfsType == vfs::NORMAL );
 	/*
 	  krUnpack->setEnabled(true);                            // unpack archive
 	  krTest->setEnabled(true);                              // test archive
@@ -962,9 +1035,15 @@ void ListPanelFunc::refreshActions() {
 }
 
 ListPanelFunc::~ListPanelFunc() {
-	// clear the view - to avoid a repaint crash
-	panel->view->clear();
-	delete files(); // delete all vfs objects
+	if( !vfsP ) {
+		if( vfsP->vfs_canDelete() )
+			delete vfsP;
+		else {
+			connect( vfsP, SIGNAL( deleteAllowed() ), vfsP, SLOT( deleteLater() ) );
+			vfsP->vfs_requestDelete();
+		}
+	}
+	vfsP = 0;
 }
 
 vfs* ListPanelFunc::files() {
@@ -999,7 +1078,8 @@ void ListPanelFunc::pasteFromClipboard() {
 
 		KURL destUrl = panel->virtualPath();
 
-		KIO::Job* job = new KIO::CopyJob( urls, destUrl, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, false, true );
+		KIO::Job* job = PreservingCopyJob::createCopyJob( PM_DEFAULT, urls,
+			 destUrl, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, false, true );
 		job->setAutoErrorHandlingEnabled( true );
 		connect( job, SIGNAL( result( KIO::Job* ) ), SLOTS, SLOT( refresh() ) );
 	}
