@@ -40,6 +40,7 @@
 #include <kio/global.h>
 #include <kurl.h>
 #include "../VFS/ftp_vfs.h"
+#include "../VFS/virt_vfs.h"
 
 
 class KRQuery;
@@ -62,7 +63,7 @@ private:
 signals:
   void finished();
   void searching(const QString&);
-  void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm);
+  void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm, QString textFound);
 
 private:
   bool stopSearch;
@@ -72,6 +73,7 @@ private:
   QStringList results;
   
   ftp_vfs *remote_vfs;
+  virt_vfs *virtual_vfs;
 };
 
 #endif
