@@ -36,6 +36,7 @@
 #include <qobject.h>
 #include <qptrvector.h>
 #include <qprogressdialog.h>
+#include <qcolor.h>
 
 typedef enum 
 {
@@ -43,9 +44,14 @@ typedef enum
   TT_DIFFERS       = 1,   // the files are differents -> don't know what to do
   TT_COPY_TO_LEFT  = 2,   // the right file is newer  -> copy from right to left
   TT_COPY_TO_RIGHT = 3,   // the left file is newer   -> copy from left to right
-  TT_DELETE        = 4    // the left file is single  -> delete it
+  TT_DELETE        = 4,   // the left file is single  -> delete it
+  TT_MAX           = 5    // the maximum number of task types
 } TaskType;
 
+#define DECLARE_COLOR_NAME_ARRAY  QString COLOR_NAMES[] = { "Equals", "Differs", "LeftCopy", "RightCopy", "Delete" }
+#define DECLARE_BACKGROUND_DFLTS  QColor BCKG_DFLTS[] = { QColor(), QColor(), QColor(), QColor(), Qt::red }
+#define DECLARE_FOREGROUND_DFLTS  QColor FORE_DFLTS[] = { Qt::black, Qt::red,  Qt::blue, Qt::darkGreen, Qt::white }
+
 #define SWAP( A, B, TYPE )      {TYPE TMP = A; A = B; B = TMP;}
 #define REVERSE_TASK( A, asym ) {switch( A )                                           \
                                  {                                                     \
@@ -76,6 +82,12 @@ class SynchronizerFileItem
     KIO::filesize_t       m_rightSize;    // the file size at the right directory
     time_t                m_leftDate;     // the file date at the left directory
     time_t                m_rightDate;    // the file date at the left directory
+    QString               m_leftLink;     // the left file's symbolic link destination
+    QString               m_rightLink;    // the right file's symbolic link destination
+    QString               m_leftOwner;    // the left file's owner
+    QString               m_rightOwner;   // the right file's owner
+    QString               m_leftGroup;    // the left file's group
+    QString               m_rightGroup;   // the right file's group
     TaskType              m_task;         // the task with the file
     bool                  m_isDir;        // flag, indicates that the file is a directory
     SynchronizerFileItem *m_parent;       // pointer to the parent directory item or 0
@@ -88,13 +100,15 @@ class SynchronizerFileItem
   public:
     SynchronizerFileItem(QString leftNam, QString rightNam, QString leftDir, QString rightDir, bool mark, 
                        bool exL, bool exR, KIO::filesize_t leftSize, KIO::filesize_t rightSize,
-                       time_t leftDate, time_t rightDate, TaskType tsk, bool isDir,
-                       bool tmp, SynchronizerFileItem *parent ) :
+                       time_t leftDate, time_t rightDate, QString leftLink, QString rightLink, 
+                       QString leftOwner, QString rightOwner, QString leftGroup, QString rightGroup, 
+                       TaskType tsk, bool isDir, bool tmp, SynchronizerFileItem *parent ) :
                        m_leftName( leftNam ), m_rightName( rightNam ), m_leftDirectory( leftDir ),  m_rightDirectory( rightDir ),
                        m_marked( mark ),  m_existsLeft( exL ), m_existsRight( exR ), m_leftSize( leftSize ),
-                       m_rightSize( rightSize ), m_leftDate( leftDate ),
-                       m_rightDate( rightDate ),m_task( tsk ), m_isDir( isDir ),
-                       m_parent(parent), m_userData( 0 ), m_overWrite( false ),
+                       m_rightSize( rightSize ), m_leftDate( leftDate ), m_rightDate( rightDate ),
+                       m_leftLink( leftLink ), m_rightLink( rightLink ), m_leftOwner( leftOwner ),
+                       m_rightOwner( rightOwner ), m_leftGroup( leftGroup ), m_rightGroup( rightGroup ),
+                       m_task( tsk ), m_isDir( isDir ), m_parent(parent), m_userData( 0 ), m_overWrite( false ),
                        m_destination( QString::null ), m_temporary( tmp ),
                        m_originalTask( tsk ) {}
 
@@ -111,6 +125,12 @@ class SynchronizerFileItem
     inline KIO::filesize_t        rightSize()             {return m_rightSize;}
     inline time_t                 leftDate()              {return m_leftDate;}
     inline time_t                 rightDate()             {return m_rightDate;}
+    inline QString                leftLink()              {return m_leftLink;}
+    inline QString                rightLink()             {return m_rightLink;}
+    inline QString                leftOwner()             {return m_leftOwner;}
+    inline QString                rightOwner()            {return m_rightOwner;}
+    inline QString                leftGroup()             {return m_leftGroup;}
+    inline QString                rightGroup()            {return m_rightGroup;}
     inline TaskType               task()                  {return m_task;}
     inline bool                   isDir()                 {return m_isDir;}
     inline SynchronizerFileItem * parent()                {return m_parent;}
@@ -129,6 +149,9 @@ class SynchronizerFileItem
                                                            SWAP( m_leftDirectory, m_rightDirectory, QString );
                                                            SWAP( m_leftSize, m_rightSize, KIO::filesize_t );
                                                            SWAP( m_leftDate, m_rightDate, time_t );
+                                                           SWAP( m_leftLink, m_rightLink, QString );
+                                                           SWAP( m_leftOwner, m_rightOwner, QString );
+                                                           SWAP( m_leftGroup, m_rightGroup, QString );
                                                            REVERSE_TASK( m_originalTask, asym );
                                                            REVERSE_TASK( m_task, asym );}
 };
@@ -143,7 +166,7 @@ class Synchronizer : public QObject
   public:
     Synchronizer();
     int     compare( QString leftURL, QString rightURL, KRQuery *query, bool subDirs, bool symLinks,
-                     bool igDate, bool asymm, bool cmpByCnt, bool igCase, bool autoSc );
+                     bool igDate, bool asymm, bool cmpByCnt, bool igCase, bool autoSc, QStringList &selFiles );
     void    stop() {stopped = true;}
     void    setMarkFlags( bool left, bool equal, bool differs, bool right, bool dup, bool sing, bool del );
     int     refresh( bool nostatus=false );
@@ -186,6 +209,8 @@ class Synchronizer : public QObject
     void    comparePercent(KIO::Job *, unsigned long);
     
   private:
+    bool    isDir( const vfile * file );
+    QString readLink( const vfile * file );
     vfs *   getDirectory( QString urlIn );
     vfile * searchFile( vfs *vfs, QString file );
     
@@ -193,18 +218,25 @@ class Synchronizer : public QObject
                               QString leftDir, QString rightDir, QString addLeftName=QString::null,
                               QString addRightName=QString::null, QString addLeftDir=QString::null, 
                               QString addRightDir=QString::null, time_t addLTime=0, time_t addRTime=0,
+                              QString leftLink=QString::null, QString rightLink=QString::null, 
+                              QString leftOwner=QString::null, QString rightOwner=QString::null, 
+                              QString leftGroup=QString::null, QString rightGroup=QString::null, 
                               bool isTemp = false );
-    void    addSingleDirectory( SynchronizerFileItem *, QString, QString, time_t, bool, bool );
+    void    addSingleDirectory( SynchronizerFileItem *, QString, QString, time_t, QString, 
+                                QString, QString, bool, bool );
     SynchronizerFileItem * addItem( SynchronizerFileItem *, QString, QString, QString, QString,
-                                    bool, bool, KIO::filesize_t, KIO::filesize_t,
-                                    time_t, time_t, TaskType, bool, bool);
+                                    bool, bool, KIO::filesize_t, KIO::filesize_t, time_t, time_t,
+                                    QString, QString, QString, QString, QString, QString, TaskType, bool, bool);
     SynchronizerFileItem * addLeftOnlyItem( SynchronizerFileItem *, QString, QString,
-                                            KIO::filesize_t, time_t, bool isDir = false, bool isTemp = false );
+                                            KIO::filesize_t, time_t, QString, QString, QString,
+                                            bool isDir = false, bool isTemp = false );
     SynchronizerFileItem * addRightOnlyItem( SynchronizerFileItem *, QString, QString,
-                                             KIO::filesize_t, time_t, bool isDir = false, bool isTemp = false  );
+                                             KIO::filesize_t, time_t, QString,  QString, QString,
+                                             bool isDir = false, bool isTemp = false  );
     SynchronizerFileItem * addDuplicateItem( SynchronizerFileItem *, QString, QString, QString, QString,
                                              KIO::filesize_t, KIO::filesize_t, time_t,
-                                             time_t, bool isDir = false, bool isTemp = false  );
+                                             time_t, QString, QString, QString, QString, QString, 
+                                             QString, bool isDir = false, bool isTemp = false  );
     bool    isMarked( TaskType task, bool dupl );
     bool    markParentDirectories( SynchronizerFileItem * );
     void    executeTask();
@@ -274,7 +306,8 @@ class Synchronizer : public QObject
     KIO::TransferJob                 *leftReadJob;    // compare left read job
     KIO::TransferJob                 *rightReadJob;   // compare right read job
     QByteArray                        compareArray;   // the array for comparing
-    QTimer                           *timer;          // timer to show the process dialog at compare by content
+    QTimer                           *timer;          // timer to show the process dialog at compare by content        
+    QStringList                       selectedFiles;  // the selected files to compare
 };
 
 #endif /* __SYNCHRONIZER_H__ */
