@@ -47,7 +47,7 @@ public:
  ~arc_vfs();
 	
 	// copy a file to the vfs (physical)
-	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify=0,QString dir = "");	
+	void    vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify=0,QString dir = "",  PreserveMode pmode = PM_DEFAULT );	
 	// remove a file from the vfs (physical)
 	void 		vfs_delFiles(QStringList *fileNames);	
 	// return a path to the file
