@@ -45,7 +45,7 @@ public:
 	~ftp_vfs();
 
 	/// Copy a file to the vfs (physical).
-	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "");
+	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "", PreserveMode pmode = PM_DEFAULT );
 	/// Remove a file from the vfs (physical)
 	virtual void vfs_delFiles(QStringList *fileNames);
 	/// Return a list of URLs for multiple files
@@ -71,7 +71,6 @@ public slots:
 	bool populateVfsList(const KURL& origin, bool showHidden);
 
 protected:
-	vfileDict  vfs_files;    //< List of pointers to vfile.
 	KURL origin_backup;         //< used to backup the old URL when refreshing to a new one,
 	bool busy;
 	bool listError;     
