@@ -55,9 +55,6 @@
 #include "../krslots.h"
 
 normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
-  setVfsFilesP(&vfs_files);
-  vfs_files.setAutoDelete(true);
-  
   vfs_type=NORMAL;
 }
 
@@ -87,9 +84,6 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 	krConfig->setGroup("Advanced");
 	if (krConfig->readBoolEntry("AutoMount",_AutoMount)) krMtMan.autoMount(path);
 	
-	krConfig->setGroup("General");
-	bool mtm    = !mimeTypeMagicDisabled && krConfig->readBoolEntry("Mimetype Magic",_MimetypeMagic);
-
 	DIR* dir = opendir(path.local8Bit());
 	if(!dir) 
 	{
@@ -115,7 +109,7 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 		// we dont need the ".",".." enteries
 		if (name=="." || name == "..") continue;
 	  
-		vfile* temp = vfileFromName(name,mtm);
+		vfile* temp = vfileFromName(name);
     addToList(temp);
   }
 	// clean up
@@ -133,13 +127,17 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 }
 
 // copy a file to the vfs (physical)	
-void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir){
-  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+void normal_vfs::vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir, PreserveMode pmode ){
+  //if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+  if( watcher ) {
+    delete watcher;   // stopScan is buggy, leaves reference on the directory, that's why we delete the watcher
+    watcher = 0;
+  }
 
-	KURL dest;
-	dest.setPath(vfs_workingDir()+"/"+dir);
+  KURL dest;
+  dest.setPath(vfs_workingDir()+"/"+dir);
 
-  KIO::Job* job = new KIO::CopyJob(*fileUrls,dest,mode,false,true );
+  KIO::Job* job = PreservingCopyJob::createCopyJob( pmode, *fileUrls,dest,mode,false,true );
   connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh()) );
   if(mode == KIO::CopyJob::Move) // notify the other panel
     connect(job,SIGNAL(result(KIO::Job*)),toNotify,SLOT(vfs_refresh(KIO::Job*)) );
@@ -152,9 +150,13 @@ void normal_vfs::vfs_delFiles(QStringList *fileNames){
 	KURL::List filesUrls;
 	KURL url;
 	QDir local( vfs_workingDir() );
-  vfile* vf;
+	vfile* vf;
 
-  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+//  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+	if( watcher ) {
+		delete watcher;   // stopScan is buggy, leaves reference on the directory, that's why we delete the watcher
+		watcher = 0;
+	}
 
 	// names -> urls
 	for(uint i=0 ; i<fileNames->count(); ++i){
@@ -208,45 +210,21 @@ void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
   KURL::List fileUrls;
   KURL url , dest;
 
-  if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+  //if( watcher ) watcher->stopScan(); // we will refresh manually this time...	
+  if( watcher ) {
+    delete watcher;   // stopScan is buggy, leaves reference on the directory, that's why we delete the watcher
+    watcher = 0;
+  }
 
   url.setPath( vfs_workingDir()+"/"+fileName );
   fileUrls.append(url);
-	dest.setPath(vfs_workingDir()+"/"+newName);
+  dest.setPath(vfs_workingDir()+"/"+newName);
 
   KIO::Job *job = new KIO::CopyJob(fileUrls,dest,KIO::CopyJob::Move,true,false );
-	connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
+  connect(job,SIGNAL(result(KIO::Job*)),this,SLOT(vfs_refresh(KIO::Job*)));
 }
 
-void normal_vfs::vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool* stop){
-  if ( *stop ) return;
-  if (!name.contains("/")) name = vfs_workingDir()+"/"+name;
-  if (name == "/proc") return;
-
-  KFileItem kfi( KFileItem::Unknown, KFileItem::Unknown, vfs::fromPathOrURL( name ) );
-  if(kfi.isLink() || !kfi.isDir()){ // single files are easy : )
-    ++(*totalFiles);
-    (*totalSize) += kfi.size();
-  }
-  else{  // handle directories
-		QDir dir(name);
-    // avoid a nasty crash on un-readable dirs
-		if ( !kfi.isReadable() || !dir.exists() ) return;
-		++(*totalDirs);
-    dir.setFilter(QDir::All|QDir::Hidden);
-	  dir.setSorting(QDir::Name|QDir::DirsFirst);
-	
-	  // recurse on all the files in the directory
-	  QFileInfoList* fileList = const_cast<QFileInfoList*>(dir.entryInfoList());
-	  for (QFileInfo* qfiP = fileList->first(); qfiP != 0; qfiP = fileList->next()){
-      if ( *stop ) return;
-      if (qfiP->fileName() != "." && qfiP->fileName() != "..")
-	      vfs_calcSpace(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs,stop);
-	  }
-  }
-}
-
-vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
+vfile* normal_vfs::vfileFromName(const QString& name){
 	QString path = vfs_workingDir()+"/"+name;
 	
 	KDE_struct_stat stat_p;
@@ -257,7 +235,7 @@ vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
 	if( S_ISDIR(stat_p.st_mode) ) perm[0] = 'd';
 	
 	KURL mimeUrl = fromPathOrURL(path);
-	QString mime=KMimeType::findByURL( mimeUrl,stat_p.st_mode,true,!mimeTypeMagic)->name();
+	QString mime=QString::null;
 
 	char symDest[256];
 	bzero(symDest,256); 
@@ -265,7 +243,7 @@ vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
 		int endOfName=0;
 		endOfName=readlink(path.local8Bit(),symDest,256);
 		if ( endOfName != -1 ){
-			if ( QDir(QString::fromLocal8Bit( symDest ) ).exists() || mime.contains("directory") ) perm[0] = 'd';
+			if ( QDir(QString::fromLocal8Bit( symDest ) ).exists() ) perm[0] = 'd';
 			if ( !QDir(vfs_workingDir()).exists( QString::fromLocal8Bit ( symDest ) ) ) mime = "Broken Link !";
 		}
 		else krOut << "Failed to read link: "<< path<<endl;
@@ -273,7 +251,7 @@ vfile* normal_vfs::vfileFromName(const QString& name,bool mimeTypeMagic){
 	
 	// create a new virtual file object
 	vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
-                          stat_p.st_gid,mime,symDest,stat_p.st_mode);
+                          stat_p.st_gid,mime,QString::fromLocal8Bit( symDest ),stat_p.st_mode);
 	temp->vfile_setUrl( mimeUrl );
 	return temp;
 }
@@ -287,23 +265,29 @@ void normal_vfs::vfs_slotRefresh()
 	refreshTimer.start( maxRefreshFrequency, true );
 }
 
+bool normal_vfs::burstRefresh(const QString& path ){
+	if( path == vfs_getOrigin().path(-1) ) {
+		if( !refreshTimer.isActive() ) {
+			// the directory itself is dirty - full refresh is needed
+			QTimer::singleShot(0, this, SLOT( vfs_slotRefresh() ) ); // safety: dirty signal comes from KDirWatch!
+			return true;
+		}
+		disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
+		connect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
+		dirty = true;
+		return true;
+	}
+	return false;
+}
+
 void normal_vfs::vfs_slotDirty(const QString& path){ 
 	if( disableRefresh ){
 		dirty = true;
 		return;
 	}
 	
-	if( path == vfs_getOrigin().path(-1) ){
-		if( !refreshTimer.isActive() ) {
-			// the directory itself is dirty - full refresh is needed
-			QTimer::singleShot(0, this, SLOT( vfs_slotRefresh() ) ); // safety: dirty signal comes from KDirWatch!
-			return;
-		}
-		disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
-		connect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
-		dirty = true;
-		return;                
-	}
+	if( burstRefresh( path ) )
+		return;        
 	
 	KURL url = fromPathOrURL(path);
 	QString name = url.fileName();
@@ -313,7 +297,7 @@ void normal_vfs::vfs_slotDirty(const QString& path){
 	
 	// we have an updated file..
 	removeFromList(name);
-	vfile* vf = vfileFromName(name,true);
+	vfile* vf = vfileFromName(name);
 	addToList(vf);
 	emit updatedVfile(vf);
 }
@@ -324,13 +308,17 @@ void normal_vfs::vfs_slotCreated(const QString& path){
 		return;
 	}	
 	
+	if( burstRefresh( path ) )
+		return;        
+	
+	
 	KURL url = fromPathOrURL(path);
 	QString name = url.fileName();	
 	// if it's in the CVS - it's an update not new file
 	if( vfs_search(name) )
 		return vfs_slotDirty(path);
 	
-	vfile* vf = vfileFromName(name,true);
+	vfile* vf = vfileFromName(name);
 	addToList(vf);
 	emit addedVfile(vf);	
 }
@@ -341,6 +329,10 @@ void normal_vfs::vfs_slotDeleted(const QString& path){
 		return;
 	}
 	
+	if( burstRefresh( path ) )
+		return;        
+	
+	
 	KURL url = fromPathOrURL(path);
 	QString name = url.fileName();
 	
