@@ -36,6 +36,7 @@
 #include <sys/types.h>
 // KDE includes
 #include <kio/global.h>
+#include <kmimetype.h>
 
 /**
  * The Virtual File class handles all the details of maintaining a single
@@ -86,7 +87,6 @@ public:
 	inline const QString&   vfile_getPerm()    const { return vfile_perm;           }
 	inline bool             vfile_isDir()      const { return (vfile_perm[0]=='d'); }
 	inline bool             vfile_isSymLink()  const { return vfile_symLink;        }
-	inline const QString&   vfile_getMime()    const { return vfile_mimeType;       }
 	inline const QString&   vfile_getSymDest() const { return vfile_symDest;        }
 	inline mode_t           vfile_getMode()    const { return vfile_mode;           }
 	inline uid_t            vfile_getUid()     const { return vfile_ownerId;        }
@@ -94,6 +94,7 @@ public:
 	inline time_t           vfile_getTime_t()  const { return vfile_time_t;         }
 	inline const KURL&      vfile_getUrl()     const { return vfile_url;            }
   
+	const QString&          vfile_getMime(bool fast=false);
 	const QString&          vfile_getOwner();
 	const QString&          vfile_getGroup();
 	const KIO::UDSEntry     vfile_getEntry(); //< return the UDSEntry from the vfile
@@ -106,12 +107,16 @@ public:
 	 * displayed size of the viewitem and thus the vfile. For INTERNAL USE !
 	 */
 	inline void             vfile_setSize(KIO::filesize_t size) {vfile_size = size;}
-	inline void             vfile_setUrl(const KURL& url){ vfile_url = url; }
+	inline void             vfile_setUrl(const KURL& url)       {vfile_url = url;  }
+
+	inline void             vfile_setIcon(const QString& icn)   {vfile_icon = icn; }
+	inline QString          vfile_getIcon();
+
 	virtual ~vfile(){}
 
 protected:
 	// the file information list
-	QString 	       vfile_name;     //< file name
+	QString          vfile_name;     //< file name
 	KIO::filesize_t  vfile_size;     //< file size
 	mode_t           vfile_mode;     //< file mode
 	uid_t            vfile_ownerId;  //< file owner id
@@ -125,6 +130,20 @@ protected:
 	QString          vfile_mimeType; //< file mimetype
 	QString          vfile_symDest;  //< if it's a sym link - its detination
 	KURL             vfile_url;      //< file URL - empty by default
+	QString          vfile_icon;     //< the name of the icon file
 };
 
+	
+QString vfile::vfile_getIcon(){
+	if( vfile_icon.isEmpty() ){
+		QString mime = this->vfile_getMime();
+      if ( mime == "Broken Link !" )
+         vfile_icon = "file_broken";
+      else {
+         vfile_icon = KMimeType::mimeType( mime ) ->icon( QString::null, true );
+      }		
+	}
+	return vfile_icon;
+}
+
 #endif
