@@ -35,17 +35,30 @@
 #include <time.h>
 #include <qeventloop.h>
 #include <kapplication.h>
+#include <klargefile.h>
+#include <qdir.h>
 #include "vfs.h"
 #include "../krusader.h"
 #include "../defaults.h"
 
-vfs::vfs(QObject* panel, bool quiet): quietMode(quiet),disableRefresh(false),mimeTypeMagicDisabled( false ),
-                                      invalidated(true),vfileIterator(0) {
-		if ( panel ){
-	 		connect(this,SIGNAL(startUpdate()),panel,SLOT(slotStartUpdate()));
-	 		connect(this,SIGNAL(incrementalRefreshFinished( const KURL& )),panel,SLOT(slotGetStats( const KURL& )));
-		}
-		else quietMode = true;
+vfs::vfs(QObject* panel, bool quiet): quietMode(quiet),disableRefresh(false),
+                                      invalidated(true),vfileIterator(0),deletePossible( true ),
+                                      deleteRequested( false ) {
+		
+
+	setVfsFilesP( new vfileDict() );
+	if ( panel ){
+		connect(this,SIGNAL(startUpdate()),panel,SLOT(slotStartUpdate()));
+		connect(this,SIGNAL(incrementalRefreshFinished( const KURL& )),panel,SLOT(slotGetStats( const KURL& )));
+	}
+	else quietMode = true;
+}
+
+vfs::~vfs() {
+	if( !deletePossible )
+		fprintf( stderr, "INTERNAL ERROR: trying to delete vfs while it is used! This may cause crash. Hoping the best...\n" );
+	clear(); // please don't remove this line. This informs the view about deleting the references
+	delete vfs_filesP;
 }
 
 KIO::filesize_t vfs::vfs_totalSize(){
@@ -109,15 +122,19 @@ KURL vfs::fromPathOrURL( const QString &originIn )
 void vfs::setVfsFilesP(vfileDict* dict){
 	vfs_filesP=dict;
 	vfs_searchP = dict;
+	dict->setAutoDelete(true);
 	if( vfileIterator ) delete vfileIterator;
 	vfileIterator = new QDictIterator<vfile>(*dict);
 }
 
 bool vfs::vfs_refresh(){ 
+	if( invalidated ) // invalidated fs requires total refresh
+		return vfs_refresh( vfs_getOrigin() );
+	
 	dirty = false;
 	// point the vfs_filesP to a NEW (empty) dictionary
 	vfs_filesP = new vfileDict();
-	//vfs_filesP->setAutoDelete(true);
+	vfs_filesP->setAutoDelete(true);
 	
 	// and populate it
 	krConfig->setGroup("Look&Feel");
@@ -164,7 +181,7 @@ bool vfs::vfs_refresh(){
 	vfileDict *temp = vfs_filesP;
 	vfs_filesP = vfs_searchP;
 	delete temp;
-	emit incrementalRefreshFinished( vfs_origin );        
+	emit incrementalRefreshFinished( vfs_origin );
 	
 	return res; 
 }
@@ -195,8 +212,33 @@ void vfs::vfs_enableRefresh(bool enable){
 	dirty = false;
 }
 
+void vfs::clear()
+{
+	emit cleared();
+	vfs_filesP->clear();
+}
+
+bool vfs::vfs_processEvents() {
+	if( deleteRequested )
+		return false;        
+	deletePossible = false;
+	qApp->eventLoop() ->processEvents( QEventLoop::AllEvents | QEventLoop::WaitForMore );
+	deletePossible = true;        
+	if( deleteRequested ) {
+		emit deleteAllowed();
+		return false;
+	}        
+	return true;                
+}
+
+void vfs::vfs_requestDelete() {
+	if( deletePossible )
+		emit deleteAllowed();
+	deleteRequested = true;
+}
+
 /// to be implemented
-#if KDE_IS_VERSION(3,3,0) && 0
+#if KDE_IS_VERSION(3,3,0)
 #include <kdirsize.h>
 void vfs::slotKdsResult( KIO::Job* job){
 	if( job && !job->error() ){
@@ -209,21 +251,101 @@ void vfs::slotKdsResult( KIO::Job* job){
 }
 
 void vfs::vfs_calcSpace( QString name , KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
-	if ( stop && *stop ) return ;
+	calculateURLSize( vfs_getFile( name ), totalSize, totalFiles, totalDirs, stop );
+}        
+        
+void vfs::calculateURLSize( KURL url,  KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
+	if ( stop && *stop ) return ;        
 	kds_busy = stop;
 	kds_totalSize  = totalSize ;
 	kds_totalFiles = totalFiles;
 	kds_totalDirs  = totalDirs;
-	KDirSize* kds  = KDirSize::dirSizeJob( vfs_getFile( name ) );
+
+	if( url.isLocalFile() ) {
+		vfs_calcSpaceLocal( url.path(-1), totalSize, totalFiles, totalDirs, stop );
+		return;
+	} else {
+		stat_busy = true;
+		KIO::StatJob* statJob = KIO::stat( url, false );
+		connect( statJob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotStatResultArrived( KIO::Job* ) ) );
+		while ( !(*stop) && stat_busy ) {usleep(1000);}
+		if( entry.isEmpty()  ) return; // statJob failed
+		KFileItem kfi(entry, url, true );        
+		if( kfi.isFile() || kfi.isLink() ) {
+			*totalFiles++;
+			*totalSize += kfi.size();
+			return;
+		}
+	}
+	
+	KDirSize* kds  = KDirSize::dirSizeJob( url );
 	connect( kds, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotKdsResult( KIO::Job* ) ) );
 	while ( !(*stop) ){ 
 		// we are in a sepetate thread - so sleeping is OK
 		usleep(1000);
 	}
 }
+
+void vfs::vfs_calcSpaceLocal(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool* stop){
+  if ( *stop ) return;
+  if (!name.contains("/")) name = vfs_workingDir()+"/"+name;
+  if (name == "/proc") return;
+
+  KDE_struct_stat stat_p;                // KDE lstat is necessary as QFileInfo and KFileItem 
+  KDE_lstat(name.local8Bit(),&stat_p);   //         reports wrong size for a symbolic link
+  
+  if( S_ISLNK(stat_p.st_mode) || !S_ISDIR(stat_p.st_mode) ) { // single files are easy : )
+    ++(*totalFiles);
+    (*totalSize) += stat_p.st_size;
+  }
+  else{  // handle directories
+    // avoid a nasty crash on un-readable dirs
+    bool readable = false;
+    if( stat_p.st_uid == getuid() )
+      readable = !!(S_IRUSR & stat_p.st_mode);
+    else if ( stat_p.st_gid == getgid() )
+      readable = !!(S_IRGRP & stat_p.st_mode );
+    else
+      readable = !!(S_IROTH & stat_p.st_mode );
+    
+    if( !readable )
+      return;
+      
+    QDir dir(name);    
+    if ( !dir.exists() ) return;
+    
+    ++(*totalDirs);
+    dir.setFilter(QDir::All | QDir::System | QDir::Hidden);
+    dir.setSorting(QDir::Name | QDir::DirsFirst);
+
+    // recurse on all the files in the directory
+    QFileInfoList* fileList = const_cast<QFileInfoList*>(dir.entryInfoList());
+    for (QFileInfo* qfiP = fileList->first(); qfiP != 0; qfiP = fileList->next()){
+      if ( *stop ) return;
+      if (qfiP->fileName() != "." && qfiP->fileName() != "..")
+        vfs_calcSpaceLocal(name+"/"+qfiP->fileName(),totalSize,totalFiles,totalDirs,stop);
+    }
+  }
+}
+
+        
+void vfs::slotStatResultArrived( KIO::Job* job ) {
+	if( !job || job->error() ) entry = KIO::UDSEntry();
+	else entry = static_cast<KIO::StatJob*>(job)->statResult();
+	stat_busy = false;
+}
+        
 #else
 void vfs::slotKdsResult(KIO::Job *job){/* empty */}
 void vfs::vfs_calcSpace( QString /*name*/ , KIO::filesize_t* /*totalSize*/, unsigned long* /*totalFiles*/, unsigned long* /*totalDirs*/, bool* /*stop*/ ) {/* empty*/}
 #endif
 
+QValueList<vfile*> vfs::vfs_search(const KRQuery& filter) {
+	QValueList<vfile*> result;
+	for ( vfile *vf = vfs_getFirstFile(); vf != 0 ; vf = vfs_getNextFile() )
+		if (filter.match(vf)) 
+			result.append(vf);
+	return result;
+}
+
 #include "vfs.moc"
