@@ -32,7 +32,7 @@
 
 // QT includes
 #include <qstring.h>
-#include <qptrlist.h>
+#include <qvaluelist.h>
 #include <qobject.h>
 #include <qdict.h>
 // KDE includes
@@ -40,6 +40,8 @@
 #include <kio/jobclasses.h>
 // Krusader includes
 #include "vfile.h"
+#include "preservingcopyjob.h"
+#include "krquery.h"
 
 /**
  * The vfs class is an extendable class which by itself does (almost)
@@ -58,10 +60,10 @@ public:
 	 * @param quiet if true, the VFS will not display error messages
 	 */
 	vfs(QObject* panel, bool quiet=false);
-	virtual			~vfs(){}
+	virtual			~vfs();
 
 	/// Copy a file to the vfs (physical).
-	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "")=0;	
+	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "", PreserveMode pmode = PM_DEFAULT)=0;	
 	/// Remove a file from the vfs (physical)
 	virtual void vfs_delFiles(QStringList *fileNames)=0;	
 	/// Return a list of URLs for multiple files	
@@ -74,6 +76,8 @@ public:
 	virtual void vfs_rename(const QString& fileName,const QString& newName)=0;
 	/// Calculate the amount of space occupied by a file or directory (recursive).
 	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
+	/// Calculate the amount of space occupied by a local file or directory (recursive).
+	virtual void vfs_calcSpaceLocal(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
 
 	/// Return the VFS working dir
 	virtual QString vfs_workingDir()=0;
@@ -81,42 +85,52 @@ public:
 	virtual bool vfs_isWritable() { return isWritable; }
 	/// Return vfile* or 0 if not found
 	inline vfile* vfs_search(const QString& name){ return (*vfs_searchP)[name]; } 
-
+	/// Return an empty vfile* list if not found
+	QValueList<vfile*> vfs_search(const KRQuery& filter);
 	/// The total size of all the files in the VFS,
 	KIO::filesize_t vfs_totalSize();
 	/// The number of files in the VFS
 	inline unsigned long vfs_noOfFiles() { return vfs_filesP->count(); }
 	/// Returns the VFS url.
 	inline KURL vfs_getOrigin()          { return vfs_origin;          }
-	// Return the VFS type.
+	/// Return the VFS type.
 	inline VFS_TYPE vfs_getType()        { return vfs_type;            }
 	/// Return the first file in the VFS and set the internal iterator to the beginning of the list.
 	inline vfile* vfs_getFirstFile(){ return (vfileIterator ? vfileIterator->toFirst() : 0); }
 	/// Return the the next file in the list and advance the iterator.
 	inline vfile* vfs_getNextFile() { return (vfileIterator ? ++(*vfileIterator) : 0);  }
-    // KDE FTP proxy bug correction
-    static KURL fromPathOrURL( const QString &originIn );
+	/// returns true if the vfs can be deleted without crash        
+	virtual bool vfs_canDelete() { return deletePossible; } 
+	/// process the application events               
+	virtual bool vfs_processEvents();        
+	/// process the application events               
+	virtual void vfs_requestDelete();        
+	/// process the application events               
+	virtual bool vfs_isDeleting()    { return deleteRequested; }
+   // KDE FTP proxy bug correction
+   static KURL fromPathOrURL( const QString &originIn );
 
 
 public slots:
 	/// Re-reads files and stats and fills the vfile list
 	virtual bool vfs_refresh(const KURL& origin);
 	/// Used to refresh the VFS when a job finishs. it calls the refresh() slot
-  /// or display a error message if the job fails
+	/// or display a error message if the job fails
 	virtual bool vfs_refresh(KIO::Job* job);
 	virtual bool vfs_refresh();
 	virtual void vfs_setQuiet(bool beQuiet){ quietMode=beQuiet; }
 	virtual void vfs_enableRefresh(bool enable);        
-	virtual void vfs_disableMimeTypeMagic( bool disable ) { mimeTypeMagicDisabled = disable; }
-	virtual void vfs_invalidate() { invalidated = true; }
-        
-signals: 	
+	virtual void vfs_invalidate() { invalidated = true; }          
+
+signals:
 	void startUpdate(); //< emitted when the VFS starts to refresh its list of vfiles.
 	void startJob(KIO::Job* job);
 	void incrementalRefreshFinished( const KURL& ); //< emitted when the incremental refresh was finished
 	void addedVfile(vfile* vf);
 	void deletedVfile(const QString& name);
 	void updatedVfile(vfile* vf);
+	void cleared();
+	void deleteAllowed();                
 
 protected:
 	/// Feel the vfs dictionary with vfiles, must be implemented for each vfs
@@ -124,25 +138,28 @@ protected:
 	/// Set the vfile list pointer
 	void setVfsFilesP(vfileDict* dict);
 	/// clear and delete all current vfiles
-	inline void clear(){ vfs_filesP->clear(); }
+	inline void clear();
 	/// Add a new vfile to the list.
 	inline void addToList(vfile *data){ vfs_filesP->insert(data->vfile_getName(),data); }
 	/// Deletes a vfile from the list.
 	inline void removeFromList(QString name){ vfs_filesP->remove(name); }
 
+	/// Deletes a vfile from the list.
+	void calculateURLSize(KURL url,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
+        
 	VFS_TYPE      vfs_type;     //< the vfs type.
 	KURL          vfs_origin;   //< the path or file the VFS originates from.
 	bool quietMode;             //< if true the vfs won't display error messages or emit signals
 	bool disableRefresh;        //< true if refresh is disabled
 	bool isWritable;            //< true if it's writable
 	bool dirty;                 //< true if a watcher signal arrived while in disabled refresh.
-	bool mimeTypeMagicDisabled; //< true if the mime type magic is disabled
 	bool invalidated;           //< the content of the cache is invalidated
 	
 protected slots:
-	// The slot for the KDirSize job
+	/// The slot for the KDirSize job
 	void slotKdsResult(KIO::Job *job);
-	
+	void slotStatResultArrived(KIO::Job *job);
+        
 private:
 	vfileDict*  vfs_filesP;    //< Point to a lists of virtual files (vfile).
 	vfileDict*  vfs_searchP;   //< Searches are preformed in this dictionary (usualy points to vfs_files)	
@@ -150,6 +167,10 @@ private:
 	
 	// used in the calcSpace function
 	bool* kds_busy;
+	bool  stat_busy;
+	bool  deletePossible;        
+	bool  deleteRequested;
+	KIO::UDSEntry entry;        
 	KIO::filesize_t* kds_totalSize;
 	unsigned long*   kds_totalFiles;
 	unsigned long*   kds_totalDirs;
