@@ -40,9 +40,6 @@ virt_vfs::virt_vfs( QObject* panel, bool quiet ) : vfs( panel, quiet ) {
 	// set the writable attribute
 	isWritable = true;
 
-	vfs_files.setAutoDelete( true );
-	setVfsFilesP( &vfs_files );
-
 	virtVfsDict.setAutoDelete( true );
 	if ( virtVfsDict.isEmpty() ) {
 		restore();
@@ -84,7 +81,7 @@ bool virt_vfs::populateVfsList( const KURL& origin, bool /*showHidden*/ ) {
 	return true;
 }
 
-void virt_vfs::vfs_addFiles( KURL::List *fileUrls, KIO::CopyJob::CopyMode /*mode*/, QObject* /*toNotify*/, QString /*dir*/ ) {
+void virt_vfs::vfs_addFiles( KURL::List *fileUrls, KIO::CopyJob::CopyMode /*mode*/, QObject* /*toNotify*/, QString /*dir*/, PreserveMode /*pmode*/ ) {
 	if ( path == "/" ) {
 		if ( !quietMode )
 			KMessageBox::error( krApp, i18n( "You can't copy files directly to the 'virt:/' directory.\nYou can create a sub directory and copy your files into it." ), i18n( "Error" ) );
@@ -121,7 +118,11 @@ void virt_vfs::vfs_delFiles( QStringList *fileNames ) {
 	// delete of move to trash ?
 	krConfig->setGroup( "General" );
 	if ( krConfig->readBoolEntry( "Move To Trash", _MoveToTrash ) ) {
+#if KDE_IS_VERSION(3,4,0)
+		job = KIO::trash( filesUrls, true );
+#else
 		job = new KIO::CopyJob( filesUrls, KGlobalSettings::trashPath(), KIO::CopyJob::Move, false, true );
+#endif
 		connect( job, SIGNAL( result( KIO::Job* ) ), krApp, SLOT( changeTrashIcon() ) );
 	} else
 		job = new KIO::DeleteJob( filesUrls, false, true );
@@ -206,16 +207,16 @@ vfile* virt_vfs::stat( const KURL& url ) {
 	}
 	KFileItem* kfi;
 	if ( url.isLocalFile() ) {
-		kfi = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, url );
+		kfi = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, url, true );
 	}
 	else {
 		busy = true;
 		KIO::StatJob* statJob = KIO::stat( url, false );
 		connect( statJob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotStatResult( KIO::Job* ) ) );
-		while ( busy ) qApp->processEvents();
+		while ( busy && vfs_processEvents() );
 		if( entry.isEmpty()  ) return 0; // statJob failed
 		
-		kfi = new KFileItem(entry, url );
+		kfi = new KFileItem(entry, url, true );
 	}
 	
 	if ( !kfi->time( KIO::UDS_MODIFICATION_TIME ) ){
@@ -238,11 +239,11 @@ vfile* virt_vfs::stat( const KURL& url ) {
 	mode_t mode = kfi->mode() | kfi->permissions();
 	QString perm = KRpermHandler::mode2QString( mode );
 // set the mimetype
-	QString mime = kfi->mimetype();
+	QString mime = QString::null;
 	QString symDest = "";
 	if ( symLink ) {
 		symDest = kfi->linkDest();
-		if ( kfi->isDir() || mime.contains( "directory" ) ) perm[ 0 ] = 'd';
+		if ( kfi->isDir() ) perm[ 0 ] = 'd';
 	}
 
 	// create a new virtual file object
@@ -308,5 +309,16 @@ bool virt_vfs::restore(){
 	return true;
 }
 
+void virt_vfs::vfs_calcSpace( QString name , KIO::filesize_t* totalSize, unsigned long* totalFiles, unsigned long* totalDirs, bool* stop ) {
+	if ( stop && *stop ) return ;
+	if( path == "/" ) {
+		KURL::List* urlList = virtVfsDict[ name ];
+		if ( urlList )
+			for( int i=0; (i != urlList->size()) && !(*stop); i++ )
+				calculateURLSize( (*urlList)[ i ], totalSize, totalFiles, totalDirs, stop );
+		return;        
+	}                
+	return vfs::vfs_calcSpace( name, totalSize, totalFiles, totalDirs, stop );
+}
 
 #include "virt_vfs.moc"
