@@ -33,7 +33,7 @@ public:
 	~virt_vfs();
 	
 	/// Copy a file to the vfs (physical).
-	void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "");	
+	void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "",  PreserveMode pmode = PM_DEFAULT );	
 	/// Remove a file from the vfs (physical)
 	void vfs_delFiles(QStringList *fileNames);	
 	/// Return a list of URLs for multiple files	
@@ -44,6 +44,8 @@ public:
 	void vfs_mkdir(const QString& name);
 	/// Rename file
 	void vfs_rename(const QString& fileName,const QString& newName);
+	/// Calculate the amount of space occupied by a file or directory (recursive).
+	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
 	
 	/// Return the VFS working dir
 	QString vfs_workingDir(){ return QString::null; }
@@ -62,7 +64,6 @@ protected:
 	bool populateVfsList(const KURL& origin, bool showHidden);
 	vfile* stat(const KURL& url);
 	
-	vfileDict  vfs_files;    //< List of pointers to vfile.
 	static QDict<KURL::List> virtVfsDict;
 	static KConfig* virt_vfs_db;
 	bool busy;
