@@ -88,6 +88,12 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "MountMan/kmountman.h"
 #include "BookMan/krbookmarkhandler.h"
 #include "Dialogs/popularurls.h"
+#include "GUI/krremoteencodingmenu.h"
+#include "Dialogs/checksumdlg.h"
+
+#ifdef __KJSEMBED__
+#include "KrJS/krjs.h"
+#endif
 
 // define the static members
 Krusader *Krusader::App = 0;
@@ -97,6 +103,8 @@ KAction *Krusader::actUnpack = 0;
 KAction *Krusader::actTest = 0;
 KAction *Krusader::actCompare = 0;
 KAction *Krusader::actCalculate = 0;
+KAction *Krusader::actCreateChecksum = 0;
+KAction *Krusader::actMatchChecksum = 0;
 KAction *Krusader::actSelect = 0;
 KAction *Krusader::actSelectAll = 0;
 KAction *Krusader::actUnselect = 0;
@@ -150,8 +158,12 @@ KAction *Krusader::actF7 = 0;
 KAction *Krusader::actF8 = 0;
 KAction *Krusader::actF9 = 0;
 KAction *Krusader::actF10 = 0;
+KAction *Krusader::actLocationBar = 0;
 KAction *Krusader::actPopularUrls = 0;
+KAction *Krusader::actJumpBack = 0;
+KAction *Krusader::actSetJumpBack = 0;
 KToggleAction *Krusader::actToggleTerminal = 0;
+KToggleAction *Krusader::actVerticalMode = 0;
 KRadioAction  *Krusader::actMarkNewerAndSingle = 0;
 KRadioAction  *Krusader::actMarkSingle = 0;
 KRadioAction  *Krusader::actMarkNewer = 0;
@@ -167,12 +179,13 @@ KrBookmarkHandler *Krusader::bookman = 0;
 //QTextOStream *Krusader::_krOut = QTextOStream(::stdout);
 
 #ifdef __KJSEMBED__
-KJSEmbed::KJSEmbedPart *Krusader::js = 0;
+KrJS *Krusader::js = 0;
 KAction *Krusader::actShowJSConsole = 0;
 #endif
 
 // construct the views, statusbar and menu bars and prepare Krusader to start
-Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
+Krusader::Krusader() : KParts::MainWindow(0,0,WType_TopLevel|WDestructiveClose|Qt::WStyle_ContextHelp),
+status(NULL), sysTray( 0 ), isStarting( true ) {
 	// parse command line arguments
    KCmdLineArgs * args = KCmdLineArgs::parsedArgs();
 
@@ -230,51 +243,63 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
 
    // init the protocol handler
    KgProtocols::init();
+   
+   // init the checksum tools
+   initChecksumModule();
 
    krConfig->setGroup( "Startup" );             
-   QStringList l1( krConfig->readPathListEntry( "Left Tab Bar" ) );
-   QStringList l2( krConfig->readPathListEntry( "Right Tab Bar" ) );
+   QStringList leftTabs = krConfig->readPathListEntry( "Left Tab Bar" );
+   QStringList rightTabs = krConfig->readPathListEntry( "Right Tab Bar" );
+   int         leftActiveTab = krConfig->readNumEntry( "Left Active Tab", 0 );
+   int         rightActiveTab = krConfig->readNumEntry( "Right Active Tab", 0 );
+   QString     startProfile = krConfig->readEntry("Starter Profile Name", QString::null );
    
-   QString leftPath, rightPath, startProfile;   
    // get command-line arguments
    if ( args->isSet( "left" ) ) {
-      leftPath = args->getOption( "left" );
+      leftTabs = QStringList::split( ',', args->getOption( "left" ) );
+      
+      leftActiveTab = 0;
+      
       // make sure left or right are not relative paths
-      if ( !leftPath.startsWith( "/" ) && leftPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
-         leftPath = QDir::currentDirPath() + "/" + leftPath;
-   } else leftPath = QString::null;
+      for(unsigned int i = 0; i != leftTabs.count(); i++ )
+      {
+        leftTabs[ i ] = leftTabs[ i ].stripWhiteSpace();
+        if( !leftTabs[ i ].startsWith( "/" ) && leftTabs[ i ].find( ":/" ) < 0 )
+          leftTabs[ i ] = QDir::currentDirPath() + "/" + leftTabs[ i ];
+      }
+      startProfile = QString::null;
+   }
    if ( args->isSet( "right" ) ) {
-      rightPath = args->getOption( "right" );
+      rightTabs = QStringList::split( ',', args->getOption( "right" ) );
+      
+      rightActiveTab = 0;
+      
       // make sure left or right are not relative paths
-      if ( !rightPath.startsWith( "/" ) && rightPath.find( ":/" ) < 0 )    // make sure we don't touch things like ftp://
-         rightPath = QDir::currentDirPath() + "/" + rightPath;
-   } else rightPath = QString::null;
-   if ( args->isSet( "profile" ) ) {
-      startProfile = args->getOption( "profile" );
-   } else startProfile = QString::null;
+      for(unsigned int i = 0; i != rightTabs.count(); i++ )
+      {
+        rightTabs[ i ] = rightTabs[ i ].stripWhiteSpace();
+        if( !rightTabs[ i ].startsWith( "/" ) && rightTabs[ i ].find( ":/" ) < 0 )
+          rightTabs[ i ] = QDir::currentDirPath() + "/" + rightTabs[ i ];
+      }
+      startProfile = QString::null;
+   }
+            
+   if ( args->isSet( "profile" ) )
+    startProfile = args->getOption( "profile" );
+   
+   if( !startProfile.isEmpty() ) {
+      leftTabs.clear();
+      rightTabs.clear();      
+      leftActiveTab = rightActiveTab = 0;
+   }
+   
+   if( leftTabs.count() == 0 )
+     leftTabs.push_back( QDir::homeDirPath() );
+   if( rightTabs.count() == 0 )
+     rightTabs.push_back( QDir::homeDirPath() );
    
    // starting the panels
-   mainView->start( leftPath, rightPath );
-
-   // restore TabBar
-   if (!runKonfig && startProfile.isEmpty() ) {
-      QStringList::const_iterator it;
-      
-      krConfig->setGroup( "Startup" );             
-      if ( krConfig->readEntry( "Left Panel Origin" ) == i18n( "the last place it was" ) )
-         for ( it = ++(l1.begin()); it != l1.end(); ++it )
-           mainView->leftMng->slotNewTab( *it );
-
-      krConfig->setGroup( "Startup" );             
-      if ( krConfig->readEntry( "Right Panel Origin" ) == i18n( "the last place it was" ) )
-         for ( it = ++(l2.begin()); it != l2.end(); ++it )
-           mainView->rightMng->slotNewTab( *it );
-   
-      krConfig->setGroup( "Startup" );             
-      mainView->leftMng->setActiveTab( krConfig->readNumEntry( "Left Active Tab", 0 ) );
-      krConfig->setGroup( "Startup" );             
-      mainView->rightMng->setActiveTab( krConfig->readNumEntry( "Right Active Tab", 0 ) );
-   }
+   mainView->start( leftTabs, leftActiveTab, rightTabs, rightActiveTab );
    
    // create the user menu
    userMenu = new UserMenu( this );
@@ -290,7 +315,8 @@ Krusader::Krusader() : KParts::MainWindow(), sysTray( 0 ), isStarting( true ) {
 
    // This enables Krusader to show a tray icon
    sysTray = new KSystemTray( this );
-   sysTray->setPixmap( iconLoader->loadIcon( "krusader", KIcon::Panel, 22 ) );
+   // Krusader::privIcon() returns either "krusader_blue" or "krusader_red" if the user got root-privileges
+   sysTray->setPixmap( iconLoader->loadIcon( privIcon(), KIcon::Panel, 22 ) );
    sysTray->hide();
 
    setCentralWidget( mainView );
@@ -352,7 +378,7 @@ bool Krusader::versionControl() {
 
    // first installation of krusader
    if ( firstRun ) {
-      KMessageBox::information( krApp, i18n( "Welcome to Krusader! As this is your first run, Krusader will now run Konfigurator." ) );
+      KMessageBox::information( krApp, i18n( "<qt><b>Welcome to Krusader!</b><p>As this is your first run, your machine will now be checked for external applications. Then the Konfigurator will be launched where you can customize Krusader to your needs.</p></qt>" ) );
       retval = true;
    }
    config->writeEntry( "Version", VERSION );
@@ -363,7 +389,9 @@ bool Krusader::versionControl() {
 
 void Krusader::statusBarUpdate( QString& mess ) {
    // change the message on the statusbar for 2 seconds
-   statusBar() ->message( mess, 5000 );
+   if (status) // ugly!!!! But as statusBar() creates a status bar if there is no, I have to ask status to prevent 
+               // the creation of the KDE default status bar instead of KrusaderStatus.
+      statusBar() ->message( mess, 5000 );
 }
 
 void Krusader::showEvent ( QShowEvent * ) {
@@ -448,7 +476,7 @@ void Krusader::setupActions() {
    actToggleCmdline = new KToggleAction( i18n( "Show &Command Line" ), 0, SLOTS,
                                          SLOT( toggleCmdline() ), actionCollection(), "toggle command line" );
    actToggleCmdline->setChecked( true );
-   actToggleTerminal = new KToggleAction( i18n( "Show Terminal &Emulator" ), 0, SLOTS,
+   actToggleTerminal = new KToggleAction( i18n( "Show Terminal &Emulator" ), ALT + CTRL + Key_T, SLOTS,
                                           SLOT( toggleTerminal() ), actionCollection(), "toggle terminal emulator" );
    actToggleTerminal->setChecked( false );
    actToggleHidden = new KToggleAction( i18n( "Show &Hidden Files" ), CTRL + Key_Period, SLOTS,
@@ -464,7 +492,7 @@ void Krusader::setupActions() {
    /* Shortcut disabled because of the Terminal Emulator bug. */
    actDirUp = new KAction( i18n( "Up one directory" ), "up", CTRL+Key_PageUp /*Key_Backspace*/, SLOTS, SLOT( dirUp() ), actionCollection(), "dirUp" );
    new KAction( i18n( "&Edit New File" ), "filenew", SHIFT + Key_F4, SLOTS, SLOT( editDlg() ), actionCollection(), "edit_new_file" );
-   new KAction( i18n( "Start &Root Mode Krusader" ), "krusader_red", ALT + Key_K, SLOTS, SLOT( rootKrusader() ), actionCollection(), "root krusader" );
+   new KAction( i18n( "Start &Root Mode Krusader" ), "krusader_root", ALT + Key_K, SLOTS, SLOT( rootKrusader() ), actionCollection(), "root krusader" );
 
    actTest = new KAction( i18n( "T&est Archive(s)" ), "ark", ALT + Key_E,
                           SLOTS, SLOT( testArchive() ), actionCollection(), "test archives" );
@@ -476,7 +504,11 @@ void Krusader::setupActions() {
                                    MAIN_VIEW, SLOT( profiles() ), actionCollection(), "profile" );
    actCalculate = new KAction( i18n( "Calculate &Occupied Space" ), "kcalc", 0,
                                SLOTS, SLOT( calcSpace() ), actionCollection(), "calculate" );
-   actProperties = new KAction( i18n( "&Properties" ), "help", 0,
+   actCreateChecksum = new KAction( i18n( "Create Checksum" ), "binary", 0,
+                               SLOTS, SLOT( createChecksum() ), actionCollection(), "create checksum" );
+   actMatchChecksum = new KAction( i18n( "Verify Checksum" ), "match_checksum", 0,
+                               SLOTS, SLOT( matchChecksum() ), actionCollection(), "match checksum" );
+   actProperties = new KAction( i18n( "&Properties" ), "help", ALT+Key_Enter,
                                 SLOTS, SLOT( properties() ), actionCollection(), "properties" );
    actPack = new KAction( i18n( "Pac&k" ), "kr_arc_pack", ALT + Key_P,
                           SLOTS, SLOT( slotPack() ), actionCollection(), "pack" );
@@ -527,7 +559,7 @@ void Krusader::setupActions() {
 
    actFind = new KAction( i18n( "&Search" ), "filefind", CTRL + Key_S,
                           SLOTS, SLOT( search() ), actionCollection(), "find" );
-   actLocate = new KAction( i18n( "&Locate" ), "find", CTRL + Key_L,
+   actLocate = new KAction( i18n( "&Locate" ), "find", SHIFT+CTRL + Key_L,
                             SLOTS, SLOT( locate() ), actionCollection(), "locate" );
    actSyncDirs = new KAction( i18n( "Synchronize &Directories" ), "kr_syncdirs", CTRL + Key_Y,
                               SLOTS, SLOT( slotSynchronizeDirs() ), actionCollection(), "sync dirs" );
@@ -546,7 +578,7 @@ void Krusader::setupActions() {
    actRoot = new KAction( i18n( "Root" ), "top", CTRL + Key_Backspace,
                           SLOTS, SLOT( root() ), actionCollection(), "root" );
    actSavePosition = new KAction( i18n( "Save &Position" ), 0,
-                                  krApp, SLOT( savePosition() ), actionCollection(), "save position" );
+                                  krApp, SLOT( savePosition() ), actionCollection(), "save position" );   
    actAllFilter = new KAction( i18n( "&All Files" ), SHIFT + Key_F10,
                                SLOTS, SLOT( allFilter() ), actionCollection(), "all files" );
    //actExecFilter = new KAction( i18n( "&Executables" ), SHIFT + Key_F11,
@@ -565,21 +597,27 @@ void Krusader::setupActions() {
                 SLOTS, SLOT( openLeftBookmarks() ), actionCollection(), "left bookmarks" );
 	new KAction( i18n( "Bookmarks" ), CTRL + Key_D,
                 SLOTS, SLOT( openBookmarks() ), actionCollection(), "bookmarks" );
+	new KAction( i18n( "Bookmark Current" ), CTRL + SHIFT + Key_D,
+                SLOTS, SLOT( bookmarkCurrent() ), actionCollection(), "bookmark current" );
+	new KAction( i18n( "History" ), CTRL + Key_H,
+                SLOTS, SLOT( openHistory() ), actionCollection(), "history" );
 	new KAction( i18n( "Sync Panels" ), ALT + Key_O,
 					 SLOTS, SLOT( syncPanels() ), actionCollection(), "sync panels");
    new KAction( i18n( "Left history" ), ALT + CTRL + Key_Left,
                 SLOTS, SLOT( openLeftHistory() ), actionCollection(), "left history" );
    new KAction( i18n( "Right history" ), ALT + CTRL + Key_Right,
                 SLOTS, SLOT( openRightHistory() ), actionCollection(), "right history" );
-        new KToggleAction( i18n( "Toggle Popup Panel" ), ALT + Key_Down, SLOTS,
+	new KAction( i18n( "New symlink" ), CTRL + ALT + Key_S,
+					SLOTS, SLOT( newSymlink() ), actionCollection(), "new symlink");
+   new KToggleAction( i18n( "Toggle Popup Panel" ), ALT + Key_Down, SLOTS,
                                           SLOT( togglePopupPanel() ), actionCollection(), "toggle popup panel" );
-        new KToggleAction( i18n( "Vertical Mode" ), ALT + CTRL + Key_R, MAIN_VIEW, 
+	actVerticalMode = new KToggleAction( i18n( "Vertical Mode" ), ALT + CTRL + Key_R, MAIN_VIEW, 
                                         SLOT( toggleVerticalMode() ), actionCollection(), "toggle vertical mode" );
    actNewTab = new KAction( i18n( "New tab" ), ALT + CTRL + Key_N, SLOTS,
                             SLOT( newTab() ), actionCollection(), "new tab" );
    actDupTab = new KAction( i18n( "Duplicate tab" ), ALT + CTRL + SHIFT + Key_N, SLOTS,
                             SLOT( duplicateTab() ), actionCollection(), "duplicate tab" );
-   actCloseTab = new KAction( i18n( "Close tab" ), ALT + CTRL + Key_C, SLOTS,
+   actCloseTab = new KAction( i18n( "Close tab" ), CTRL + Key_W, SLOTS,
                               SLOT( closeTab() ), actionCollection(), "close tab" );
    actNextTab  = new KAction( i18n( "Next tab" ), SHIFT + Key_Right, SLOTS,
 	     SLOT( nextTab() ), actionCollection(), "next tab" );
@@ -589,6 +627,7 @@ void Krusader::setupActions() {
                               SLOT( userMenu() ), actionCollection(), "user menu" );
    actManageUseractions = new KAction( i18n( "Manage user actions" ), 0, SLOTS,
                               SLOT( manageUseractions() ), actionCollection(), "manage useractions" );
+   new KrRemoteEncodingMenu(i18n("Select Remote Charset"), "charset", actionCollection(), "changeremoteencoding");
 
         // setup the Fn keys
         actF2 = new KAction( i18n( "F2 - Open a terminal" ), Key_F2,
@@ -611,7 +650,13 @@ void Krusader::setupActions() {
                 this, SLOT( quitKrusader() ) , actionCollection(), "F10_Quit" );
 	actPopularUrls = new KAction( i18n("Popular URLs"), CTRL+Key_Z,
 					popularUrls, SLOT( showDialog() ), actionCollection(), "Popular_Urls");
-										
+	actLocationBar = new KAction( i18n("Go to location bar"), CTRL+Key_L,
+					SLOTS, SLOT( slotLocationBar() ), actionCollection(), "location_bar");
+	actJumpBack = new KAction( i18n("Jump back"), "kr_jumpback", CTRL+Key_J,
+					SLOTS, SLOT( slotJumpBack() ), actionCollection(), "jump_back");
+	actSetJumpBack = new KAction( i18n("Set jump back point here"), "kr_setjumpback", CTRL+SHIFT+Key_J,
+					SLOTS, SLOT( slotSetJumpBack() ), actionCollection(), "set_jump_back");
+   
    // and at last we can set the tool-tips
    actSelect->setToolTip( i18n( "Select files using a filter" ) );
    actSelectAll->setToolTip( i18n("Select all files in the current directory" ) );
@@ -626,9 +671,6 @@ void Krusader::setupActions() {
    userAction = new UserAction();
    
    #ifdef __KJSEMBED__
-   js = new KJSEmbed::KJSEmbedPart();
-   // make this object, the class Krusader, available for scripting as "Krusader":
-   js->addObject( this, "Krusader" );
    actBack = new KAction( i18n( "JavaScript console" ), ALT + CTRL + Key_J, SLOTS, SLOT( jsConsole() ), actionCollection(), "JS_Console" );
    #endif
 }
@@ -668,7 +710,7 @@ void Krusader::exportKeyboardShortcuts(QString filename) {
 	QDataStream stream(&f);
 	
 	KAction *action;
-	for (int i=0; i<actionCollection()->count(); ++i) {
+	for (unsigned int i=0; i<actionCollection()->count(); ++i) {
 		action = actionCollection()->action(i);
 		int key = action->shortcut().keyCodeQt();
 		if (key) { // if a valid shortcut exists
@@ -696,35 +738,36 @@ void Krusader::savePosition() {
    config->writeEntry( "Terminal Size", mainView->vert_splitter->sizes() [ 1 ] );
    QValueList<int> lst = mainView->horiz_splitter->sizes();
    config->writeEntry( "Splitter Sizes", lst );
+   if( !MAIN_VIEW->getTerminalEmulatorSplitterSizes().isEmpty() )
+     config->writeEntry( "Terminal Emulator Splitter Sizes", MAIN_VIEW->getTerminalEmulatorSplitterSizes() );
+   
    // save view settings ---> fix when we have tabbed-browsing
    mainView->left->view->saveSettings();
    mainView->right->view->saveSettings();
+   
+   config->setGroup( "Startup" );
+   config->writeEntry( "Vertical Mode", actVerticalMode->isChecked());
    config->sync();
 }
 
 void Krusader::saveSettings() {
    toolBar() ->saveSettings( krConfig, "Private" );
-	toolBar("actionsToolBar")->saveSettings( krConfig, "Actions Toolbar" );
+   toolBar("actionsToolBar")->saveSettings( krConfig, "Actions Toolbar" );
    config->setGroup( "Startup" );
-   config->writeEntry( "Left Active Tab", mainView->leftMng->activeTab() );
-   config->writeEntry( "Right Active Tab", mainView->rightMng->activeTab() );
-   mainView->leftMng->saveSettings( krConfig, "Left Tab Bar" );
-   mainView->rightMng->saveSettings( krConfig, "Right Tab Bar" );
-   bool panelsavesettings = config->readBoolEntry( "Panels Save Settings", _PanelsSave );
+   bool panelsavesettings = config->readEntry( "Panels Save Settings", _PanelsSave ) == "Tabs";
+   if( panelsavesettings ) {
+      config->writeEntry( "Left Active Tab", mainView->leftMng->activeTab() );
+      config->writeEntry( "Right Active Tab", mainView->rightMng->activeTab() );
+      mainView->leftMng->saveSettings( krConfig, "Left Tab Bar" );
+      mainView->rightMng->saveSettings( krConfig, "Right Tab Bar" );
+   }
    bool rememberpos = config->readBoolEntry( "Remember Position", _RememberPos );
    bool uisavesettings = config->readBoolEntry( "UI Save Settings", _UiSave );
-   if ( panelsavesettings ) {
-      // left panel
-      config->writeEntry( "Left Panel Type", i18n( "List" ) );
-      config->writeEntry( "Left Panel Origin", i18n( "the last place it was" ) );
-      // right panel
-      config->writeEntry( "Right Panel Type", i18n( "List" ) );
-      config->writeEntry( "Right Panel Origin", i18n( "the last place it was" ) );
-   }
-	// save the popup panel's page of the CURRENT tab
-	config->writeEntry( "Left Panel Popup", mainView->left->popup->currentPage() );
-	config->writeEntry( "Right Panel Popup", mainView->right->popup->currentPage() );
-	
+
+   // save the popup panel's page of the CURRENT tab
+   config->writeEntry( "Left Panel Popup", mainView->left->popup->currentPage() );
+   config->writeEntry( "Right Panel Popup", mainView->right->popup->currentPage() );
+
    // save size and position
    if ( rememberpos || uisavesettings ) {
       savePosition();
@@ -738,11 +781,12 @@ void Krusader::saveSettings() {
       config->writeEntry( "Show FN Keys", actToggleFnkeys->isChecked() );
       config->writeEntry( "Show Cmd Line", actToggleCmdline->isChecked() );
       config->writeEntry( "Show Terminal Emulator", actToggleTerminal->isChecked() );
+      config->writeEntry( "Vertical Mode", actVerticalMode->isChecked());
    }
-	
-	// save popular links
-	popularUrls->save();
-	
+
+   // save popular links
+   popularUrls->save();
+
    config->sync();
 }
 
@@ -797,6 +841,10 @@ void Krusader::startWaiting( QString msg, int count , bool cancel ) {
    plzWait->startWaiting( msg , count, cancel );
 }
 
+bool Krusader::wasWaitingCancelled() const { 
+	return plzWait->wasCancelled(); 
+}
+
 void Krusader::incProgress( KProcess *, char *buffer, int buflen ) {
    int howMuch = 0;
    for ( int i = 0 ; i < buflen; ++i )
@@ -871,6 +919,11 @@ void Krusader::updateGUI( bool enforce ) {
          mainView->fnKeys->show();
          actToggleFnkeys->setChecked( true );
       }
+      // set vertical mode
+      if (krConfig->readBoolEntry( "Vertical Mode", false)) {
+      	actVerticalMode->setChecked(true);
+			mainView->toggleVerticalMode();
+      }
    }
 	// popular urls
 	popularUrls->load();
@@ -908,6 +961,29 @@ QStringList Krusader::supportedTools() {
       tools.append( "RENAME" );
       tools.append( KrServices::fullPathName( "krename" ) );
    }
+  // checksum utility
+  if (KrServices::cmdExist("md5deep")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("md5deep", "checksum utility"));
+  } else if (KrServices::cmdExist("md5sum")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("md5sum", "checksum utility"));
+  } else if (KrServices::cmdExist("sha1deep")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("sha1deep", "checksum utility"));
+  } else if (KrServices::cmdExist("sha256deep")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("sha256deep", "checksum utility"));
+  } else if (KrServices::cmdExist("tigerdeep")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("tigerdeep", "checksum utility"));
+  } else if (KrServices::cmdExist("whirlpooldeep")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("whirlpooldeep", "checksum utility"));
+  } else if (KrServices::cmdExist("cfv")) {
+      tools.append("MD5");
+      tools.append(KrServices::fullPathName("cfv", "checksum utility"));
+  }
 
    return tools;
 }
@@ -966,5 +1042,12 @@ QString Krusader::getTempFile() {
    return tmpDir;
 }
 
+char* Krusader::privIcon() {
+   if ( geteuid() )
+      return "krusader_user";
+   else
+      return "krusader_root";
+}
+
 
 #include "krusader.moc"
