@@ -49,7 +49,7 @@
 #include <kdebug.h>
 
 #ifdef __KJSEMBED__
-#include <kjsembed/kjsembedpart.h>
+class KrJS;
 #endif
 
 class KrusaderStatus;
@@ -75,6 +75,11 @@ class Krusader : public KParts::MainWindow {
     Krusader();
     ~Krusader();
     void refreshView();				 // re-create the main view
+    /**
+     * This returns a defferent icon if krusader runs with root-privileges
+     * @return a character string with the specitif icon-name
+     */
+    static char* privIcon();
     static QStringList supportedTools(); // find supported tools
 	 void importKeyboardShortcuts(QString filename);
 	 void exportKeyboardShortcuts(QString filename);
@@ -119,10 +124,10 @@ class Krusader : public KParts::MainWindow {
     static KAction *actKonfigurator, *actToolsSetup, *actBack, *actRoot, *actFind, *actDirUp;
     static KAction *actSelectColorMask, *actMultiRename, *actAllFilter, *actOpenLeftBm, *actOpenRightBm;
     static KAction *actNewTab, *actDupTab, *actCloseTab, *actPreviousTab, *actNextTab, *actSplit; 
-	 static KAction *actCombine, *actUserMenu, *actManageUseractions, *actSyncDirs, *actSyncBrowse;
-	 static KAction *actF2, *actF3, *actF4, *actF5, *actF6, *actF7, *actF8, *actF9, *actF10;
-	 static KAction *actPopularUrls;
-    static KToggleAction *actToggleTerminal;
+    static KAction *actCombine, *actUserMenu, *actManageUseractions, *actSyncDirs, *actSyncBrowse;
+    static KAction *actF2, *actF3, *actF4, *actF5, *actF6, *actF7, *actF8, *actF9, *actF10;
+    static KAction *actPopularUrls, *actLocationBar, *actJumpBack, *actSetJumpBack, *actCreateChecksum, *actMatchChecksum;
+    static KToggleAction *actToggleTerminal, *actVerticalMode;
     static KRadioAction *actMarkNewerAndSingle, *actMarkNewer, *actMarkSingle, 
                         *actMarkDifferentAndSingle, *actMarkDifferent;
     KToggleAction *actToggleFnkeys, *actToggleCmdline, *actShowToolBar,
@@ -138,6 +143,7 @@ class Krusader : public KParts::MainWindow {
     KRPleaseWaitHandler* plzWait;
     void startWaiting( QString msg = "Please Wait", int count = 0 , bool cancel = false );
     void stopWait();
+	 bool wasWaitingCancelled() const;
 
     KrusaderStatus *status;
     KRslots *slot;
@@ -150,7 +156,7 @@ class Krusader : public KParts::MainWindow {
 	 static KrBookmarkHandler *bookman;
 
     #ifdef __KJSEMBED__
-    static KJSEmbed::KJSEmbedPart *js;
+    static KrJS *js;
     static KAction *actShowJSConsole;
     #endif
   
@@ -176,12 +182,15 @@ class Krusader : public KParts::MainWindow {
 #define ACTIVE_MNG   (MAIN_VIEW->activeManager())
 #define ACTIVE_PANEL (MAIN_VIEW->activePanel)
 #define ACTIVE_FUNC  (ACTIVE_PANEL->func)
+#define OTHER_MNG		(MAIN_VIEW->inactiveManager())
 #define OTHER_PANEL	(ACTIVE_PANEL->otherPanel)
 #define OTHER_FUNC	(OTHER_PANEL->func)
 #define LEFT_PANEL	(MAIN_VIEW->left)
 #define LEFT_FUNC		(LEFT_PANEL->func)
+#define LEFT_MNG		(MAIN_VIEW->leftMng)
 #define RIGHT_PANEL  (MAIN_VIEW->right)
 #define RIGHT_FUNC	(RIGHT_PANEL->func)
+#define RIGHT_MNG		(MAIN_VIEW->rightMng)
 
 // krusader's actions - things krusader can do!
 #define krProperties      Krusader::App->actProperties     // file properties
@@ -190,6 +199,8 @@ class Krusader : public KParts::MainWindow {
 #define krTest            Krusader::App->actTest           // test archive
 #define krCompare         Krusader::App->actCompare        // compare 2 files by content
 #define krCalculate       Krusader::App->actCalculate      // calculate occupied space
+#define krCreateCS	  Krusader::App->actCreateChecksum
+#define krMatchCS	  Krusader::App->actMatchChecksum
 #define krSelect          Krusader::App->actSelect         // select a group by filter
 #define krSelectAll       Krusader::App->actSelectAll      // select all files
 #define krUnselect        Krusader::App->actUnselect       // unselect by filter
@@ -238,6 +249,9 @@ class Krusader : public KParts::MainWindow {
 #define krF9				  Krusader::App->actF9
 #define krF10				  Krusader::App->actF10
 #define krPopularUrls	  Krusader::App->actPopularUrls
+#define krLocationBar	  Krusader::App->actLocationBar
+#define krJumpBack	  Krusader::App->actJumpBack
+#define krSetJumpBack	  Krusader::App->actSetJumpBack
 
 #ifdef __KJSEMBED__
 #define krJS			Krusader::App->js
