@@ -12,8 +12,8 @@
 
 #define HIDE_ON_SINGLE_TAB  false
 
-#define SHOW  { _newTab->show(); _tabbar->show(); _closeTab->show(); }
-#define HIDE  { _newTab->hide(); _tabbar->hide(); _closeTab->hide(); }
+#define SHOW    { _newTab->show(); _tabbar->show(); _closeTab->show(); }
+#define HIDE    { _newTab->hide(); _tabbar->hide(); _closeTab->hide(); }
 
 PanelManager::PanelManager( QWidget *parent, bool left, ListPanel* &self, ListPanel* &other, ListPanel* &active ) :
 QWidget( parent, "PanelManager" ), _layout( 0 ), _left( left ), _self( self ), _other( other ), _active( active ) {
@@ -155,6 +155,9 @@ void PanelManager::slotCloseTab() {
    _stack->removeWidget( oldp );
    deletePanel( oldp );
 
+   if( ACTIVE_PANEL == oldp )
+     ACTIVE_PANEL = _self;
+
    // setup pointers
    _self->otherPanel = _other;
    _other->otherPanel = _self;
