@@ -43,6 +43,7 @@ class PanelManager: public QWidget {
     int  activeTab();
     void setActiveTab( int );
     void setCurrentTab( int );
+    void refreshAllTabs( bool invalidate = false );
 
   public slots:
     /**
@@ -62,6 +63,8 @@ class PanelManager: public QWidget {
     void slotRefreshActions();
 
   private:
+    void deletePanel( ListPanel *p );
+  
     QGridLayout *_layout;
     QHBoxLayout *_barLayout;
     bool _left;
